<?php

/*
Plugin Name: Alea Portfolio CPT
Plugin URI: http://themeforest.net/user/blueowlcreative
Description: This Plugin creates a Portfolio Custom Post Type for Alea WordPress Theme.
Version: 1.0
Author: blueowlcreative
Author URI: http://blueowlcreative.com
License: Custom
License URI: http://themeforest.net/licenses 
*/

/* ----------------------------------------------------- */
/* Add Portfolio Custom Post Type
/* ----------------------------------------------------- */
function boc_portfolio_register() {  

	// Initialize the Portfolio Metro grid specific sizes
	add_image_size( 'boc_wide', 1200, 400, true );
	add_image_size( 'boc_tall', 600, 800, true );
	add_image_size( 'boc_widetall', 1200, 800, true );

	// Check for slug/taxonomy names set in Theme options
	if( function_exists( 'ot_get_option' ) ) { 
		$portfolio_slug = ot_get_option('portfolio_slug','portfolio_item');
	}
	if((!isset($portfolio_slug)) || ($portfolio_slug == '')){
		$portfolio_slug = 'portfolio_item';
	}

	register_post_type(
		'portfolio',
		array(
			'labels' => array(
				'name' => 'Portfolio',
				'singular_name' => 'Portfolio'
			),
			'public' => true,
			'has_archive' => true,
			'rewrite' => array('slug' => $portfolio_slug),
			'supports' => array('title', 'editor', 'thumbnail'),
			'can_export' => true,
			'show_in_nav_menus' => true,
		)
	);

	register_taxonomy('portfolio_category', 'portfolio', array('hierarchical' => true, 'label' => 'Portfolio Categories', 'query_var' => true, 'rewrite' => true));
	
	
	// Remove post_format URL param so we can use PREVIEW on portfolio items
	function remove_post_format_parameter( $url ) {
		$url = remove_query_arg( 'post_format', $url );
		return $url;
	}
	add_filter( 'preview_post_link', 'remove_post_format_parameter', 9999 );	 
}
add_action('init', 'boc_portfolio_register');   



// Register the Custom Templates for the Custom Post Type Portfolio
function boc_cpt_post_types( $post_types ) {
	$post_types = array();
	$post_types[] = 'portfolio';
	return $post_types;
}
add_filter( 'cpt_post_types', 'boc_cpt_post_types' );


/**
	BOC Related Portfolio Items
**/
if( ! function_exists( 'boc_get_related_portfolio_items' ) ) { 
	function boc_get_related_portfolio_items($post_id) {
		
		$item_cats = get_the_terms($post_id, 'portfolio_category');
		if($item_cats):
		foreach($item_cats as $item_cat) {
			$item_array[] = $item_cat->term_id;
		}
		endif;

		$args = array(
			'post__not_in' => array($post_id),
			'ignore_sticky_posts' => 0,
			'post_type' => 'portfolio',
			'posts_per_page'	=> 100,
			'tax_query' => array(
				array(
					'taxonomy' => 'portfolio_category',
					'field' => 'id',
					'terms' => $item_array
				)
			)
		);
		
		$query = new WP_Query($args);
		
		wp_reset_postdata();
		
		return $query;
	}
}


/**
	BOC Main Portfolio Items Query
**/
if( ! function_exists( 'boc_get_portfolio_items' ) ) { 
	function boc_get_portfolio_items($limit = 10, $order_by = 'rand', $order = 'DESC', $category='', $paged = 1) {

		// WPML compatibility :: START
		if(isset($category) && $category){
			$categories_IDs = (explode( "," , str_replace(' ', '', $category)));
			$translated_terms = array() ;
			foreach ($categories_IDs as $cat) {
				$terms_for_wpml = get_term_by('slug', $cat, 'portfolio_category');
				$terms_for_wpml = apply_filters('wpml_object_id', $terms_for_wpml->term_id, 'custom taxonomy', true);
				$translated_terms []= get_term_by('term_id', $terms_for_wpml, 'portfolio_category')->slug;
			}
			$category = implode($translated_terms, ",");
		}
		// WPML compatibility :: END
	
		$args = array(
			'ignore_sticky_posts' 	=> 0,
			'post_type' 			=> 'portfolio',
			'orderby'				=> $order_by,
			'order'					=> $order,
			'posts_per_page' 		=> (int)$limit,
			'paged' 				=> $paged,
			'portfolio_category' 	=> $category, 
		);
		
		$query = new WP_Query($args);

		wp_reset_postdata();
		
		return $query;
	}
}

/* ----------------------------------------------------- */
/* EOF 
/* ----------------------------------------------------- */