<?php

/*
Plugin Name: Alea Shortcodes & Widgets
Plugin URI: http://themeforest.net/user/blueowlcreative
Description: This Plugin contains the Alea Theme specific Shortcodes, Elements and Widgets
Version: 1.10
Author: blueowlcreative
Author URI: http://blueowlcreative.com
Text Domain: boc-shortcodes-and-widgets
*/

if ( ! function_exists( 'boc_shortcodes_and_widgets' ) ) {

	define( 'BOC_PLUGIN_PATH', 	plugin_dir_path(__FILE__ ));
	define( 'BOC_PLUGIN_URL' , 	plugin_dir_url(__FILE__ ));

	
	add_action( 'init', 'boc_shortcodes_and_widgets' );
	
	function boc_shortcodes_and_widgets() {

		// Base Shortcodes (dropdown in editor)
		require_once BOC_PLUGIN_PATH. 'includes/base_shortcodes.php';
		
		// Load POSTs LIKE functionality if enabled
		if(function_exists('ot_get_option')){
			if(ot_get_option('posts_like_functionality','on')=='on'){
				include_once BOC_PLUGIN_PATH. 'includes/post-like.php';
			}
		}

		// Use shortcodes in Widgets
		add_filter('widget_text', 'do_shortcode');
		
		// Aqua Live Image Resizer
		include_once BOC_PLUGIN_PATH. 'includes/aq_resizer.php';
	}
	
	
	//	Register Handles used by shortcodes inline scripts and styles
	add_action( 'wp_enqueue_scripts', 'boc_register_shortcodes_styles_scripts' );
	function boc_register_shortcodes_styles_scripts() {
		
		// Register handles for Shortcodes' Inline CSS/JS that will late-load 
		wp_register_style( 'boc_shortcodes_style', false );
		wp_register_script( 'boc_shortcodes_script', false, array('alea-common'));

	}
	
	// WPB Page Builder Specific
	add_action( 'vc_before_init', 'boc_setup_VC', 1);
	

	if(!function_exists('boc_setup_VC')){
			
		function boc_setup_VC(){

			// Set custom VC templates DIR
			$vc_res_dir = BOC_PLUGIN_PATH.'/includes/vc/core';
			vc_set_shortcodes_templates_dir($vc_res_dir);

			// Add Custom CSS for Theme Shortcodes in VC in Admin
			if ( !function_exists( 'boc_load_admin_scripts' ) ) {
				function boc_load_admin_scripts() {
					wp_enqueue_style( 'boc-admin-css-icons', get_template_directory_uri().'/stylesheets/icons.css');
					wp_enqueue_style( 'boc-admin-css', BOC_PLUGIN_URL.'assets/css/admin.css', array('js_composer'));
				}
			}
			add_action( 'admin_enqueue_scripts', 'boc_load_admin_scripts' );
			
			
			// Replace VC waypoints, we'll use our own in libs.js
			if ( !function_exists( 'boc_remove_VC_default_waypoints' ) ) {
				function boc_remove_VC_default_waypoints() {
					// Dequeue VC waypoints.js that is dynamically included when an animated element is found
					wp_deregister_script('waypoints');
				}
			}
			add_action( 'vc_base_register_front_js', 'boc_remove_VC_default_waypoints', 100);
			

			// Include shortcodes
			foreach ( glob( plugin_dir_path( __FILE__ ) . "includes/vc/*.php" ) as $file ) {

				include_once $file;
			}

			// Remove VC default modules
			boc_modify_default_VC_modules();
			

			// Set VC by default for Page & Portfolio post types
			vc_set_default_editor_post_types(array('page',	'portfolio'));

			// Add BOC Studio
			if(!function_exists('add_boc_studio_to_vc')) {
				function add_boc_studio_to_vc() {
					if (is_admin()) {
						include_once BOC_PLUGIN_PATH. 'includes/boc_studio_templates.php';
					}
				}
			}
			add_boc_studio_to_vc();
		}
	}
}


/**
 * Add a default-gravatar to options
 */
if ( !function_exists('boc_addgravatar') ) {
	function boc_addgravatar( $avatar_defaults ) {
		$myavatar = get_template_directory_uri() . '/images/comment_avatar.png';
		$avatar_defaults[$myavatar] = 'BlueOwl Default Avatar';
		return $avatar_defaults;
	}
	add_filter( 'avatar_defaults', 'boc_addgravatar' );
}


// Remove stuff from default Visual Composer if set in Theme Options
if ( !function_exists( 'boc_modify_default_VC_modules' )) {
	function boc_modify_default_VC_modules(){

	
		// Remove Default VC templates
		add_filter( 'vc_load_default_templates', 'boc_custom_VC_templates' );
		function boc_custom_VC_templates( $data ) {
			return array(); // This will remove all default templates. 
		}	
	
	
		if ( function_exists('vc_remove_element') ) {
			if ( !function_exists( 'boc_vc_modules_remove' )) {
				function boc_vc_modules_remove() {
					vc_remove_element('vc_wp_tagcloud');
					vc_remove_element('vc_wp_archives');
					vc_remove_element('vc_wp_calendar');
					vc_remove_element('vc_wp_pages');
					vc_remove_element('vc_wp_links');
					vc_remove_element('vc_wp_posts');
					vc_remove_element('vc_wp_custommenu');
					vc_remove_element('vc_wp_search');
					vc_remove_element('vc_wp_recentcomments');
					
					vc_remove_element('vc_posts_grid');
					vc_remove_element('vc_posts_slider');
					vc_remove_element('vc_carousel');
					vc_remove_element('vc_separator');
					vc_remove_element('vc_gallery');
					vc_remove_element('vc_pie');
					vc_remove_element('vc_flickr');
					vc_remove_element('vc_progress_bar');
					vc_remove_element('vc_toggle');
					vc_remove_element('vc_accordion');
					vc_remove_element('vc_cta');
					vc_remove_element('vc_btn');
					vc_remove_element('vc_button');
					vc_remove_element('vc_button2');
					vc_remove_element('vc_cta_button');
					vc_remove_element('vc_cta_button2');
					vc_remove_element('vc_wp_categories');
					vc_remove_element('vc_wp_rss');
					vc_remove_element('vc_wp_text');
					vc_remove_element('vc_wp_meta');
					vc_remove_element('vc_custom_heading');
					vc_remove_element('vc_icon');
					vc_remove_element('vc_empty_space');
					vc_remove_element('vc_tabs');
					vc_remove_element('vc_tour');
					vc_remove_element('vc_message');
					vc_remove_element('vc_tta_pageable');
					
					vc_remove_element('vc_basic_grid');
					vc_remove_element('vc_media_grid');
					vc_remove_element('vc_masonry_grid');
					vc_remove_element('vc_masonry_media_grid');
					vc_remove_element('vc_images_carousel');
					vc_remove_element('layerslider_vc');
					vc_remove_element('vc_text_separator');
					
					
					vc_remove_element('vc_tta_tabs');
					vc_remove_element('vc_tta_tour');
					vc_remove_element('vc_tta_accordion');
					vc_remove_element('vc_round_chart');
					vc_remove_element('vc_line_chart');
					
					vc_remove_element('vc_hoverbox');
					vc_remove_element('vc_zigzag');
					vc_remove_element('vc_gutenberg');
					
					
					//vc_remove_element('add_to_cart_url');
					//vc_remove_element('product_attribute');
				
				} // End function
			} 
			if(function_exists('ot_get_option')){
				if ( function_exists('vc_remove_element') && (ot_get_option('boc_hide_core_vc_elements','on')=='on')) {
					//add_action( 'init', 'boc_vc_modules_remove' );
					boc_vc_modules_remove();
				}
				
				// Enable SVG Upload if set in Theme Options
				if(ot_get_option('enable_svg_upload','off')=='on'){
					
					function cc_mime_types($mimes) {
					  $mimes['svg'] = 'image/svg+xml';
					  return $mimes;
					}
					add_filter('upload_mimes', 'cc_mime_types');
				}
			}	
			
		} 

		
		if ( !function_exists( 'boc_modify_VC_elements' )) {
			function boc_modify_VC_elements() {
				
				// Rearrange element Weight a bit
				if ( function_exists('vc_map_update') ) {
					// Row
					$settings = array (
					  'weight' => 100
					);
					vc_map_update( 'vc_row', $settings );
					
					// Image
					$settings = array (
					  'weight' => 75
					);
					vc_map_update( 'vc_single_image', $settings );
					
					// Text
					$settings = array (
					  'weight' => 76
					);
					vc_map_update( 'vc_column_text', $settings );
				}


				// Modify Animations to be custom for column and image elements
				vc_remove_param( 'vc_single_image', 'css_animation' );
				vc_remove_param( 'vc_column_text', 'css_animation' );
				
				$attributes = array(
					"type"		=> "dropdown",
					"heading"	=> esc_html__("CSS Animation", "boc-shortcodes-and-widgets"),
					"param_name"	=> "css_animation",
					"admin_label"	=> true,
					"value"			=> array(
						esc_html__("None", "boc-shortcodes-and-widgets")					=> '',
						esc_html__("Top to bottom", "boc-shortcodes-and-widgets")			=> "boc_animate_when_almost_visible boc_top-to-bottom",
						esc_html__("Bottom to top", "boc-shortcodes-and-widgets")			=> "boc_animate_when_almost_visible boc_bottom-to-top",
						esc_html__("Left to right", "boc-shortcodes-and-widgets")			=> "boc_animate_when_almost_visible boc_left-to-right",
						esc_html__("Right to left", "boc-shortcodes-and-widgets")			=> "boc_animate_when_almost_visible boc_right-to-left",
						esc_html__("Fade In", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_fade-in",
						esc_html__("Zoom In", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_zoom",
						esc_html__("Zoom Out", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_zoom_out",
						esc_html__("Blur In", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_blur"),
					"description"	=> esc_html__("Select one if you want this element to be animated once it enters the browsers viewport.", "boc-shortcodes-and-widgets"),
					"edit_field_class" =>"vc_col-sm-6 mt_15",
				);				
				$attributes2 = array(
					"type"		=> "dropdown",
					"heading"	=> esc_html__("CSS Animation", "boc-shortcodes-and-widgets"),
					"param_name"	=> "css_animation",
					"admin_label"	=> true,
					"value"			=> array(
						esc_html__("None", "boc-shortcodes-and-widgets")					=> '',
						esc_html__("Top to bottom", "boc-shortcodes-and-widgets")			=> "boc_animate_when_almost_visible boc_top-to-bottom",
						esc_html__("Bottom to top", "boc-shortcodes-and-widgets")			=> "boc_animate_when_almost_visible boc_bottom-to-top",
						esc_html__("Left to right", "boc-shortcodes-and-widgets")			=> "boc_animate_when_almost_visible boc_left-to-right",
						esc_html__("Right to left", "boc-shortcodes-and-widgets")			=> "boc_animate_when_almost_visible boc_right-to-left",
						esc_html__("Fade In", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_fade-in",
						esc_html__("Zoom In", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_zoom",
						esc_html__("Zoom Out", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_zoom_out",
						esc_html__("Blur In", "boc-shortcodes-and-widgets")				=> "boc_animate_when_almost_visible boc_blur"),
					"description"	=> esc_html__("Select one if you want this element to be animated once it enters the browsers viewport.", "boc-shortcodes-and-widgets"),
					"edit_field_class" =>"vc_col-sm-6",
				);
				vc_add_param( 'vc_single_image', $attributes );
				vc_add_param( 'vc_column_text', $attributes2 );
				
				// Add optional delay
				$attributes = array(
					"type" => "textfield",
					"heading" => esc_html__("Override Delay (ms)", 'boc-shortcodes-and-widgets'),
					"param_name" => "delay",
					"value" => "",
					"description" => esc_html__("Override the default delay for the CSS animation (e.g. 2000)", 'boc-shortcodes-and-widgets'),
					"edit_field_class" =>"vc_col-sm-6",
					"dependency"	=> Array(
						'element'	=> "css_animation",
						'not_empty'	=> true,
					)
				);
				vc_add_param( 'vc_single_image', $attributes );
				vc_add_param( 'vc_column_text', $attributes );
				
				
				// Mofidy Image Element
				vc_remove_param( 'vc_single_image', 'img_size' );
				vc_remove_param( 'vc_single_image', 'title' );
				vc_remove_param( 'vc_single_image', 'image' );
				

				$attributes = array(
					"type" => "attach_image",
					"heading" => esc_html__("Image", "boc-shortcodes-and-widgets"),
					"param_name" => "image",
					"description" => esc_html__("Select image from media library.", "boc-shortcodes-and-widgets"),
					"weight"		=> 1,
				);
				vc_add_param( 'vc_single_image', $attributes );
				
				$attributes = array(
					"type"		=> "dropdown",
					"heading"	=> esc_html__("Image Size", "boc-shortcodes-and-widgets"),
					"param_name"	=> "img_size",			
					"value"			=> array(
						esc_html__("Full Size", "boc-shortcodes-and-widgets")		=> 'full',
						esc_html__("Large", "boc-shortcodes-and-widgets")			=> "large",
						esc_html__("Medium", "boc-shortcodes-and-widgets")			=> "boc_medium",
						esc_html__("Small", "boc-shortcodes-and-widgets")			=> "medium",
						esc_html__("Thumbnail", "boc-shortcodes-and-widgets")		=> "thumbnail"),
					"weight"		=> 1,
				);
				vc_add_param( 'vc_single_image', $attributes ); 


				// Add Row Overlay
				vc_add_param('vc_row',array(
					'type' => 'colorpicker',
					'heading' => esc_html__('Color', 'boc-shortcodes-and-widgets'),
					'param_name' => 'boc_overlay_color',
					'value' => '',
					'description' => esc_html__('Select color and opacity','boc-shortcodes-and-widgets'),
					"edit_field_class" =>"vc_col-sm-6",
					'group' => esc_html__("Overlay", 'boc-shortcodes-and-widgets'),
				));
				
				vc_add_param('vc_row',array(
					"type"			=> 'checkbox',
					"heading" 		=> esc_html__("Use gradient?", 'boc-shortcodes-and-widgets'),
					"param_name" 		=> "boc_with_gradient",
					"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
					"description" 	=> esc_html__("Check to use 2 color gradient", 'boc-shortcodes-and-widgets'),
					"edit_field_class" =>"vc_col-sm-6 no_top_padding",
					'group' => esc_html__("Overlay", 'boc-shortcodes-and-widgets'),
				));
				
				vc_add_param('vc_row',array(
					'type' => 'colorpicker',
					'heading' => esc_html__('Gradient Color 2', 'boc-shortcodes-and-widgets'),
					'param_name' => 'boc_overlay_color2',
					'value' => '',
					"dependency"	=> Array(
						'element'	=> "boc_with_gradient",
						'not_empty'	=> true,
					),
					'description' => esc_html__('Select color and opacity','boc-shortcodes-and-widgets'),
					"edit_field_class" =>"vc_col-sm-6",
					'group' => esc_html__("Overlay", 'boc-shortcodes-and-widgets'),
				));
				vc_add_param('vc_row',array(
					'type' => 'dropdown',
					'heading' => esc_html__('Gradient angle','boc-shortcodes-and-widgets'),
					'param_name' => 'boc_overlay_gradient_angle',
					"value"			=> array(
						esc_html__("0deg (Vertical)", "boc-shortcodes-and-widgets") => '0deg',
						esc_html__("30deg", "boc-shortcodes-and-widgets")			=> "30deg",	
						esc_html__("60deg", "boc-shortcodes-and-widgets")			=> "60deg",	
						esc_html__("90deg", "boc-shortcodes-and-widgets")			=> "90deg",	
						esc_html__("120deg", "boc-shortcodes-and-widgets")			=> "120deg",	
						esc_html__("150deg", "boc-shortcodes-and-widgets")			=> "150deg",	
						esc_html__("180deg", "boc-shortcodes-and-widgets")			=> "180deg",	
						esc_html__("210deg", "boc-shortcodes-and-widgets")			=> "210deg",	
						esc_html__("240deg", "boc-shortcodes-and-widgets")			=> "240deg",	
						esc_html__("270deg", "boc-shortcodes-and-widgets")			=> "270deg",	
						esc_html__("300deg", "boc-shortcodes-and-widgets")			=> "300deg",	
						esc_html__("330deg", "boc-shortcodes-and-widgets")			=> "330deg",		
					),
					"dependency"	=> Array(
						'element'	=> "boc_with_gradient",
						'not_empty'	=> true,
					),
					'description' => esc_html__('Select gradient angle','boc-shortcodes-and-widgets'),
					"edit_field_class" =>"vc_col-sm-6 no_top_padding",
					'group' => esc_html__("Overlay", 'boc-shortcodes-and-widgets'),
				));
				
				vc_add_param('vc_row',array(
					"type"			=> 'checkbox',
					"heading" 		=> esc_html__("Use shape border?", 'boc-shortcodes-and-widgets'),
					"param_name" 		=> "boc_add_shape_border",
					"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
					"description" 	=> esc_html__("Add a fancy Shape border to the Row", 'boc-shortcodes-and-widgets'),
					'group' => esc_html__("Overlay", 'boc-shortcodes-and-widgets'),
				));
				
				vc_add_param('vc_row',array(
					'type' => 'dropdown',
					'heading' => esc_html__('Shape Border Type','boc-shortcodes-and-widgets'),
					'param_name' => 'boc_shape_border_type',
					"value"			=> array(
						esc_html__("Wave", "boc-shortcodes-and-widgets") 			=> 'wave',
						esc_html__("Tilt Left", "boc-shortcodes-and-widgets") 	=> 'tilt_left',
						esc_html__("Tilt Right", "boc-shortcodes-and-widgets") 	=> 'tilt_right',
						esc_html__("Curve", "boc-shortcodes-and-widgets") 		=> 'curve',
						esc_html__("Triangle", "boc-shortcodes-and-widgets") 		=> 'triangle',
						esc_html__("Grunge", "boc-shortcodes-and-widgets") 		=> 'grunge',
					),
					"dependency"	=> Array(
						'element'	=> "boc_add_shape_border",
						'not_empty'	=> true,
					),
					"edit_field_class" =>"vc_col-sm-4",
					'group' => esc_html__("Overlay", 'boc-shortcodes-and-widgets'),
				));
				
				vc_add_param('vc_row',array(
					'type' => 'dropdown',
					'heading' => esc_html__('Shape Border Position','boc-shortcodes-and-widgets'),
					'param_name' => 'boc_shape_border_position',
					"value"			=> array(
						esc_html__("Top", "boc-shortcodes-and-widgets") 		=> 'top',
						esc_html__("Bottom", "boc-shortcodes-and-widgets") 	=> 'bottom',
						esc_html__("Both", "boc-shortcodes-and-widgets") 		=> 'both',
					),
					"std"	=> 'bottom',
					"dependency"	=> Array(
						'element'	=> "boc_add_shape_border",
						'not_empty'	=> true,
					),
					"edit_field_class" =>"vc_col-sm-4",
					'group' => esc_html__("Overlay", 'boc-shortcodes-and-widgets'),
				));
				
				vc_add_param('vc_row',array(
					'type' => 'textfield',
					'heading' => esc_html__('Shape Border Height','boc-shortcodes-and-widgets'),
					'param_name' => 'boc_shape_border_height',
					"value"		=> '130',
					"dependency"	=> Array(
						'element'	=> "boc_add_shape_border",
						'not_empty'	=> true,
					),
					"description" 	=> esc_html__("Enter height in 'px', e.g. 130", 'boc-shortcodes-and-widgets'),
					"edit_field_class" =>"vc_col-sm-4",
					'group' => esc_html__("Overlay", 'boc-shortcodes-and-widgets'),
				));
				vc_add_param('vc_row',array(
					'type' => 'colorpicker',
					'heading' => esc_html__('Shape Border Color', 'boc-shortcodes-and-widgets'),
					'param_name' => 'boc_shape_border_color',
					'value' => '#ffffff',
					"dependency"	=> Array(
						'element'	=> "boc_add_shape_border",
						'not_empty'	=> true,
					),
					"edit_field_class" =>"vc_col-sm-4",
					'group' => esc_html__("Overlay", 'boc-shortcodes-and-widgets'),
				));
				vc_add_param('vc_row',array(
					"type"			=> 'checkbox',
					"heading" 		=> esc_html__("Bring Shape to Front?", 'boc-shortcodes-and-widgets'),
					"param_name" 		=> "boc_shape_border_front",
					"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
					"dependency"	=> Array(
						'element'	=> "boc_add_shape_border",
						'not_empty'	=> true,
					),
					"edit_field_class" =>"vc_col-sm-8",
					"description" 	=> esc_html__("Use if you have backgrounds on top of the row e.i. in the columns.", 'boc-shortcodes-and-widgets'),
					'group' => esc_html__("Overlay", 'boc-shortcodes-and-widgets'),
				));
				
				

				// change Row icon
				$settings = array (
				  "icon"   => "boc_row",
				);
				vc_map_update( 'vc_row', $settings );	
				
				// change vc_widget_sidebar icon
				$settings = array (
				  "icon"   => "boc_widget_area",
				);
				vc_map_update( 'vc_widget_sidebar', $settings );					
			
				// change IMG icon
				$settings = array (
				  "icon"   => "boc_img",
				);
				vc_map_update( 'vc_single_image', $settings );				
			
				// change Text Block icon
				$settings = array (
				  "icon"   => "boc_text",
				);
				vc_map_update( 'vc_column_text', $settings );			
				
				// change soc btn icons
				$settings = array (
				  "icon"   => "boc_facebook",
				);
				vc_map_update( 'vc_facebook', $settings );

				$settings = array (
				  "icon"   => "boc_twitter",
				);
				vc_map_update( 'vc_tweetmeme', $settings );

				$settings = array (
				  "icon"   => "boc_google",
				);
				vc_map_update( 'vc_googleplus', $settings );

				$settings = array (
				  "icon"   => "boc_pinterest",
				);
				vc_map_update( 'vc_pinterest', $settings );

				
				// change other icons
				$settings = array (
				  "icon"   => "boc_video",
				);
				vc_map_update( 'vc_video', $settings );
				
				$settings = array (
				  "icon"   => "boc_gmaps",
				);
				vc_map_update( 'vc_gmaps', $settings );
				
				$settings = array (
				  "icon"   => "boc_html",
				);
				vc_map_update( 'vc_raw_html', $settings );
				
				$settings = array (
				  "icon"   => "boc_js",
				);
				vc_map_update( 'vc_raw_js', $settings );
				
				$settings = array (
				  "icon"   => "boc_cf7",
				);
				@vc_map_update( 'contact-form-7', $settings );
				
				$settings = array (
				  "icon"   => "boc_rev_slider",
				);
				@vc_map_update( 'rev_slider_vc', $settings );
				
				
				$settings = array (
				  "icon"   => "boc_rev_slider",
				);
				@vc_map_update( 'rev_slider', $settings );
				
				
				$settings = array (
				  "icon"   => "boc_woocommerce",
				);
				@vc_map_update( 'woocommerce_cart', $settings );
				@vc_map_update( 'woocommerce_checkout', $settings );
				@vc_map_update( 'woocommerce_order_tracking', $settings );
				@vc_map_update( 'woocommerce_my_account', $settings );
				@vc_map_update( 'featured_products', $settings );
				@vc_map_update( 'product', $settings );
				@vc_map_update( 'products', $settings );
				@vc_map_update( 'add_to_cart', $settings );
				@vc_map_update( 'add_to_cart_url', $settings );
				@vc_map_update( 'recent_products', $settings );
				@vc_map_update( 'product_page', $settings );
				@vc_map_update( 'product_category', $settings );
				@vc_map_update( 'product_categories', $settings );
				@vc_map_update( 'sale_products', $settings );
				@vc_map_update( 'best_selling_products', $settings );
				@vc_map_update( 'top_rated_products', $settings );
				@vc_map_update( 'product_attribute', $settings );
				
			}
		}
		boc_modify_VC_elements();
		
		
		// Remove 'Grid Elements' from Admin menu
		function boc_remove_grid_elements_menu(){
		  remove_menu_page( 'edit.php?post_type=vc_grid_item' );
		}
		add_action( 'admin_menu', 'boc_remove_grid_elements_menu' );


		// Remove teaser metabox
		if (is_admin()) {
			function boc_remove_meta_boxes() {
				remove_meta_box( 'vc_teaser', 'page', 		'side' );
				remove_meta_box( 'vc_teaser', 'post', 		'side' );
				remove_meta_box( 'vc_teaser', 'portfolio', 	'side' );
				remove_meta_box( 'vc_teaser', 'product', 	'side' );
			}
		//	add_action( 'admin_init', 'boc_remove_meta_boxes' );
		}
	}
}



////////////////////////////////////////////////
// Custom Widgets
////////////////////////////////////////////////

if ( ! function_exists( 'boc_load_widgets' ) ) {
	
	add_action('widgets_init', 'boc_load_widgets');
	
	function boc_load_widgets(){

		register_widget('boc_latest');
		register_widget('boc_contact_info_widget');
		register_widget('boc_header_icon_widget');
	}
	
	/**
	 * Latest Posts Widget
	 */
	class boc_latest extends WP_Widget {

			function __construct() {
				$widget_ops = array('description' => 'Alea Latest Posts');
				parent::__construct('boc_latest', 'Alea Latest Posts', $widget_ops);
			}

			function widget($args, $instance) {
				extract($args, EXTR_SKIP);
				echo $before_widget;
				$title = empty($instance['title']) ? '&nbsp;' : '<span>'.apply_filters('widget_title', wp_kses_post($instance['title'])).'</span>';
				$count = wp_kses_post($instance['count']);

				echo boc_removeSpanFromTitle($before_title) . $title . boc_removeSpanFromTitle($after_title);
				wp_reset_query();

				$recent_posts = new WP_Query(
					array(
						'posts_per_page' => $count,
						'post_status' => 'publish',
						'nopaging' => 0,
						'post__not_in' => get_option('sticky_posts')
						)
					);

				// Cycle through Posts    
				if ($recent_posts->have_posts()) :while ($recent_posts->have_posts()) : $recent_posts->the_post();
				?>

				<div class="boc_latest_posts section">
					<a href="<?php the_permalink() ?>"><?php the_post_thumbnail('boc_thumb', array( 'title' => get_the_title() )); ?></a>
					<div class="boc_latest_text">
						<h4 class="boc_latest_posts_title"><a href="<?php the_permalink() ?>"><?php the_title(); ?></a></h4>
						<p class="date"><?php echo get_the_date();?></p>
					</div>
				</div><div class="h20"></div>
					<?php
					endwhile;
					endif;
					wp_reset_query();

					echo $after_widget;
				}

				function update($new_instance, $old_instance) {
					$instance = $old_instance;
					$instance['title'] = strip_tags($new_instance['title']);

					$instance['count'] = $new_instance['count'];

					return $instance;
				}

				function form($instance) {
					$instance = wp_parse_args((array) $instance, array('title' => ''));
					$title = strip_tags($instance['title']);

					$count = $instance['count'];
					?>


					<p>
						<label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e( 'Widget Title', 'boc-shortcodes-and-widgets' ) ?>:
							<input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
						</label>
					</p>

					<p>
						<label for="<?php echo esc_attr($this->get_field_id('count')); ?>"><?php esc_html_e( 'How many posts? (Number)', 'boc-shortcodes-and-widgets' ) ?>:
							<input class="widefat" id="<?php echo esc_attr($this->get_field_id('count')); ?>" name="<?php echo esc_attr($this->get_field_name('count')); ?>" type="text" value="<?php echo esc_attr($count); ?>" />
						</label>
					</p>

					<?php
				}

	}


	/**
	 * Contact Info Widget
	 */
	class boc_contact_info_widget extends WP_Widget {
		
		function __construct()
		{
			$widget_ops = array('classname' => 'contact_info', 'description' => '');
			parent::__construct('contact_info-widget', 'Alea: Contact Info', $widget_ops);
		}
		
		function widget($args, $instance)
		{
			extract($args);
			$title = apply_filters('widget_title', $instance['title']);

			echo $before_widget;

			if($title) {
				echo $before_title.$title.$after_title;
			}
			?>
			<?php if($instance['phone']): ?>
			<div class="boc_contact_icon"><span class="icon fa fa-phone"></span> <?php echo wp_kses_post($instance['phone']); ?></div>
			<?php endif; ?>

			<?php if($instance['email']): ?>
			<div class="boc_contact_icon"><span class="icon fa fa-envelope"></span> <a href="mailto:<?php echo antispambot(esc_html($instance['email'])); ?>"><?php echo antispambot(esc_html($instance['email'])); ?></a></div>
			<?php endif; ?>

			<?php if($instance['address']): ?>
			<div class="boc_contact_icon"><span class="icon boc_i-location"></span> <?php echo wp_kses_post($instance['address']); ?></div>
			<?php endif; ?>
			
			<?php if($instance['open_hours']): ?>
			<div class="boc_contact_icon"><span class="icon fa fa-clock-o"></span> <?php echo wp_kses_post($instance['open_hours']); ?></div>
			<?php endif; ?>
			
			<div class="clear h10"></div>
			
			<?php
			echo $after_widget;
		}
		
		function update($new_instance, $old_instance)
		{
			$instance = $old_instance;

			$instance['title'] = $new_instance['title'];
			$instance['address'] = $new_instance['address'];
			$instance['phone'] = $new_instance['phone'];
			$instance['fax'] = $new_instance['fax'];
			$instance['email'] = $new_instance['email'];
			$instance['web'] = $new_instance['web'];
			$instance['open_hours'] = $new_instance['open_hours'];

			return $instance;
		}

		function form($instance)
		{
			$defaults = array('title' => 'Contact Info');
			$instance = wp_parse_args((array) $instance, $defaults); ?>
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e( 'Title', 'boc-shortcodes-and-widgets' ) ?>:</label>
				<input class="widefat" style="width: 216px;" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php echo wp_kses_post($instance['title']); ?>" />
			</p>
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('phone')); ?>"><?php esc_html_e( 'Phone', 'boc-shortcodes-and-widgets' ) ?>:</label>
				<input class="widefat" style="width: 216px;" id="<?php echo esc_attr($this->get_field_id('phone')); ?>" name="<?php echo esc_attr($this->get_field_name('phone')); ?>" value="<?php echo wp_kses_post($instance['phone']); ?>" />
			</p>
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('email')); ?>"><?php esc_html_e( 'Email', 'boc-shortcodes-and-widgets' ) ?>:</label>
				<input class="widefat" style="width: 216px;" id="<?php echo esc_attr($this->get_field_id('email')); ?>" name="<?php echo esc_attr($this->get_field_name('email')); ?>" value="<?php echo wp_kses_post($instance['email']); ?>" />
			</p>
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('address')); ?>"><?php esc_html_e( 'Address', 'boc-shortcodes-and-widgets' ) ?>:</label>
				<input class="widefat" style="width: 216px;" id="<?php echo esc_attr($this->get_field_id('address')); ?>" name="<?php echo esc_attr($this->get_field_name('address')); ?>" value="<?php echo wp_kses_post($instance['address']); ?>" />
			</p>
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('open_hours')); ?>"><?php esc_html_e( 'Open Hours', 'boc-shortcodes-and-widgets' ) ?>:</label>
				<input class="widefat" style="width: 216px;" id="<?php echo esc_attr($this->get_field_id('open_hours')); ?>" name="<?php echo esc_attr($this->get_field_name('open_hours')); ?>" value="<?php echo wp_kses_post($instance['open_hours']); ?>" />
			</p>
		<?php
		}
	} 



	/**
	 * Header Icon Text
	 */
	class boc_header_icon_widget extends WP_Widget {
		
		function __construct()
		{
			$widget_ops = array('classname' => 'boc_icon_text_item', 'description' => '');
			parent::__construct('boc_icon_text', 'Alea: Icon Text Widget', $widget_ops);
		}
		
		function widget($args, $instance)
		{
			extract($args);

			echo $before_widget;
			?>

				<?php if($instance['icon']): ?>
				<div class="icon"><i class="<?php echo html_entity_decode($instance['icon']); ?>"></i></div>
				<?php endif; ?>

				<div class="text">
					<?php if($instance['text']): ?>
					<strong><?php echo html_entity_decode($instance['text']); ?></strong>
					<?php endif; ?>
					<?php if($instance['subtext']): ?>
					<span><?php echo html_entity_decode($instance['subtext']); ?></span>
					<?php endif; ?>
				</div>

			<?php
			echo $after_widget;
		}
		
		function update($new_instance, $old_instance)
		{
			$instance = $old_instance;

			$instance['icon'] = sanitize_text_field(htmlentities($new_instance['icon']));
			$instance['text'] = sanitize_text_field(htmlentities($new_instance['text']));
			$instance['subtext'] = sanitize_text_field(htmlentities($new_instance['subtext']));

			return $instance;
		}

		function form($instance)
		{
			$defaults = array('title' => 'Icon Text');
			$instance = wp_parse_args((array) $instance, $defaults); ?>
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('icon')); ?>"><?php esc_html_e( 'Icon', 'boc-shortcodes-and-widgets' ) ?>:</label>
				<input class="widefat" style="width: 216px;" id="<?php echo $this->get_field_id('icon'); ?>" name="<?php echo $this->get_field_name('icon'); ?>" value="<?php echo $instance['icon']; ?>" />
			</p>
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('text')); ?>"><?php esc_html_e( 'Text', 'boc-shortcodes-and-widgets' ) ?>:</label>
				<input class="widefat" style="width: 216px;" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>" value="<?php echo $instance['text']; ?>" />
			</p>
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('subtext')); ?>"><?php esc_html_e( 'SubText', 'boc-shortcodes-and-widgets' ) ?>:</label>
				<input class="widefat" style="width: 216px;" id="<?php echo $this->get_field_id('subtext'); ?>" name="<?php echo $this->get_field_name('subtext'); ?>" value="<?php echo $instance['subtext']; ?>" />
			</p>
		<?php
		}
	}	
}	