<?php

/**
	Custom Google Maps
**/

// Map Shortcode in Visual Composer

if( ! function_exists( 'shortcode_boc_gmap' ) ) {

	function shortcode_boc_gmap($atts) {
		
		$atts = vc_map_get_attributes('boc_gmap', $atts );
		extract( $atts );
		
		// Add Google Maps Key
		wp_enqueue_script( 'google-maps-api', '//maps.google.com/maps/api/js?key='.esc_js($api_key) );
		
		$map_id = "map_".rand(0,10000);
		
		if(!$lat){
			$lat = 0;
		}
		
		if(!$lon){
			$lon = 0;
		}
		
		$content = '<div id="' .esc_attr($map_id) . '" style="height:' . esc_attr($height) . 'px;" class="boc_google_map"></div>';


		$getScheme = NULL;

		if(($colorscheme != '') && ($colorscheme != '1')) {
			
			$getScheme = 'styles: ';

			switch ($colorscheme) {
				
				// Default
				case 1:
					$getScheme .= '[]';
					break;
				// Vivid
				case 2:
					$getScheme .= '[{"featureType": "all","elementType": "labels.icon","stylers": [{"visibility": "off"}]},{"featureType":"landscape.man_made","elementType":"geometry","stylers":[{"color":"#f7f1df"}]},{"featureType":"landscape.natural","elementType":"geometry","stylers":[{"color":"#d0e3b4"}]},{"featureType":"landscape.natural.terrain","elementType":"geometry","stylers":[{"visibility":"off"}]},{"featureType":"poi","elementType":"labels","stylers":[{"visibility":"off"}]},{"featureType":"poi.business","elementType":"all","stylers":[{"visibility":"off"}]},{"featureType":"poi.medical","elementType":"geometry","stylers":[{"color":"#fbd3da"}]},{"featureType":"poi.park","elementType":"geometry","stylers":[{"color":"#bde6ab"}]},{"featureType":"road","elementType":"geometry.stroke","stylers":[{"visibility":"off"}]},{"featureType":"road","elementType":"labels","stylers":[{"visibility":"off"}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#ffe15f"}]},{"featureType":"road.highway","elementType":"geometry.stroke","stylers":[{"color":"#efd151"}]},{"featureType":"road.arterial","elementType":"geometry.fill","stylers":[{"color":"#ffffff"}]},{"featureType":"road.local","elementType":"geometry.fill","stylers":[{"color":"black"}]},{"featureType":"transit.station.airport","elementType":"geometry.fill","stylers":[{"color":"#cfb2db"}]},{"featureType":"water","elementType":"geometry","stylers":[{"color":"#a2daf2"}]}]';
					break;
				// Green
				case 3:
					$getScheme .= '[{"featureType":"landscape.natural","elementType":"geometry.fill","stylers":[{"visibility":"on"},{"color":"#e0efef"}]},{"featureType":"poi","elementType":"geometry.fill","stylers":[{"visibility":"on"},{"hue":"#1900ff"},{"color":"#c0e8e8"}]},{"featureType":"road","elementType":"geometry","stylers":[{"lightness":100},{"visibility":"simplified"}]},{"featureType":"road","elementType":"labels","stylers":[{"visibility":"off"}]},{"featureType":"transit.line","elementType":"geometry","stylers":[{"visibility":"on"},{"lightness":700}]},{"featureType":"water","elementType":"all","stylers":[{"color":"#7dcdcd"}]}]';
					break;
				// Blue
				case 4:
					$getScheme .= '[{"featureType":"administrative","elementType":"labels.text.fill","stylers":[{"color":"#444444"}]},{"featureType":"landscape","elementType":"all","stylers":[{"color":"#f2f2f2"}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"}]},{"featureType":"road","elementType":"all","stylers":[{"saturation":-100},{"lightness":45}]},{"featureType":"road.highway","elementType":"all","stylers":[{"visibility":"simplified"}]},{"featureType":"road.arterial","elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"}]},{"featureType":"water","elementType":"all","stylers":[{"color":"#46bcec"},{"visibility":"on"}]}]';
					break;
				// Grey
				case 5:
					$getScheme .= '[{"featureType":"water","elementType":"geometry","stylers":[{"color":"#e9e9e9"},{"lightness":17}]},{"featureType":"landscape","elementType":"geometry","stylers":[{"color":"#f5f5f5"},{"lightness":20}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#ffffff"},{"lightness":17}]},{"featureType":"road.highway","elementType":"geometry.stroke","stylers":[{"color":"#ffffff"},{"lightness":29},{"weight":0.2}]},{"featureType":"road.arterial","elementType":"geometry","stylers":[{"color":"#ffffff"},{"lightness":18}]},{"featureType":"road.local","elementType":"geometry","stylers":[{"color":"#ffffff"},{"lightness":16}]},{"featureType":"poi","elementType":"geometry","stylers":[{"color":"#f5f5f5"},{"lightness":21}]},{"featureType":"poi.park","elementType":"geometry","stylers":[{"color":"#dedede"},{"lightness":21}]},{"elementType":"labels.text.stroke","stylers":[{"visibility":"on"},{"color":"#ffffff"},{"lightness":16}]},{"elementType":"labels.text.fill","stylers":[{"saturation":36},{"color":"#333333"},{"lightness":40}]},{"elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"transit","elementType":"geometry","stylers":[{"color":"#f2f2f2"},{"lightness":19}]},{"featureType":"administrative","elementType":"geometry.fill","stylers":[{"color":"#fefefe"},{"lightness":20}]},{"featureType":"administrative","elementType":"geometry.stroke","stylers":[{"color":"#fefefe"},{"lightness":17},{"weight":1.2}]}]';
					break;
				// Dark Grey
				case 6:
					$getScheme .= '[{"featureType":"all","elementType":"labels.text.fill","stylers":[{"saturation":36},{"color":"#000000"},{"lightness":40}]},{"featureType":"all","elementType":"labels.text.stroke","stylers":[{"visibility":"on"},{"color":"#000000"},{"lightness":16}]},{"featureType":"all","elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"administrative","elementType":"geometry.fill","stylers":[{"color":"#000000"},{"lightness":20}]},{"featureType":"administrative","elementType":"geometry.stroke","stylers":[{"color":"#000000"},{"lightness":17},{"weight":1.2}]},{"featureType":"landscape","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":20}]},{"featureType":"poi","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":21}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#000000"},{"lightness":17}]},{"featureType":"road.highway","elementType":"geometry.stroke","stylers":[{"color":"#000000"},{"lightness":29},{"weight":0.2}]},{"featureType":"road.arterial","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":18}]},{"featureType":"road.local","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":16}]},{"featureType":"transit","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":19}]},{"featureType":"water","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":17}]}]';
					break;
			}
			$getScheme .= ",";
		}

		$js = '
		jQuery(window).load(function() {
			
			var latlng = new google.maps.LatLng(' . esc_js($lat) . ', ' . esc_js($lon) . ');
			var myOptions = {
				zoom: ' . esc_js($zoom) . ',
				center: latlng,
				scrollwheel: ' . (esc_js($scrollwheel) ? 'true' : 'false') .',
				disableDefaultUI: ' . (esc_js($hidecontrols) ? 'true' : 'false') .',
				panControl: false,
				draggable: !boc_is_mobile,
				streetViewControl: false,
				'. $getScheme .'
				mapTypeId: google.maps.MapTypeId.' . esc_js($maptype) . '
			};
			var ' . esc_js($map_id) . ' = new google.maps.Map(document.getElementById("' . esc_js($map_id) . '"), myOptions);
			';

			// Add address
			if(($address != '') || ($lat))
			{
				if($address != ''){
					$geocoder_address_string = "{ 'address': address}";
				}else {
					$geocoder_address_string = "{ 'location': latlng}";
				}
				$js .= '
				var geocoder_' . esc_js($map_id) . ' = new google.maps.Geocoder();
				var address = \'' . esc_js($address) . '\';
				
				geocoder_' . $map_id . '.geocode( '.$geocoder_address_string.', function(results, status) {
					if (status == google.maps.GeocoderStatus.OK) {
						' . esc_js($map_id) . '.setCenter(results[0].geometry.location);
						';
						
						if ($marker !='')
						{
							// Add custom image
							if ($markerimage !='')
							{
								$image_src = wp_get_attachment_image_src($markerimage, 'full');
								$js .= 'var image = "'. esc_url($image_src[0]) .'";';
							}
							$js .= '
							var marker = new google.maps.Marker({
								map: ' . esc_js($map_id) . ', 
								';
								if ($markerimage !='')
								{
									$js .= 'icon: image,';
								}
							$js .= '
								position: ' . esc_js($map_id) . '.getCenter()
							});
							';

							//infowindow
							if($infowindow != '') 
							{
								//first convert and decode html chars
								$thiscontent = wp_specialchars_decode(preg_replace( "/\r|\n/", "", $infowindow)); // HTML allowed, no escaping
								$js .= '
								var contentString = \'' . $thiscontent . '\';
								var infowindow = new google.maps.InfoWindow({
									content: contentString
								});
											
								google.maps.event.addListener(marker, \'click\', function() {
								  infowindow.open(' . esc_js($map_id) . ',marker);
								});
								';

								//infowindow default
								if ($infowindowdefault == 'yes')
								{
									$js .= '
									google.maps.event.addListenerOnce(' . esc_js($map_id) . ', "tilesloaded", function() {
										infowindow.open(' . esc_js($map_id) . ', marker);
									});
									';
								}
							}
						}
				$js .= '
					} else {
						alert("Geocode was not successful for the following reason: " + status);
					}
				});
				';
			}

			// Show Marker
			if ($marker != '')
			{
				// Custom image
				if ($markerimage !='')
				{
					$image_src = wp_get_attachment_image_src($markerimage, 'full');
					$js .= 'var image = "'. esc_url($image_src[0]) .'";';

				}

				$js .= '
					var marker = new google.maps.Marker({
					map: ' . esc_js($map_id) . ', 
					';
					if ($markerimage !='')
					{
						$js .= 'icon: image,';
					}
				$js .= '
					position: ' . esc_js($map_id) . '.getCenter()
				});
				';
			}

			$js .= '});';

			wp_enqueue_script( 'boc_shortcodes_script');
			wp_add_inline_script( 'boc_shortcodes_script', $js );	
			
			return $content;
	}
	
	add_shortcode('boc_gmap', 'shortcode_boc_gmap');
}


// Map Shortcode in Visual Composer
vc_map( array(
		"name"					=> esc_html__( "Custom Google Map", 'boc-shortcodes-and-widgets' ),
		"base"					=> "boc_gmap",
		"category" 				=> "Alea Shortcodes",
		"icon"					=> "boc_gmaps",
		"weight"				=> 20,
		"params"				=> array(
			array(
				"type"			=> "textfield",
				"admin_label"	=> true,
				"heading"		=> esc_html__( "Address", 'boc-shortcodes-and-widgets' ),
				"param_name"	=> "address",
				"description"	=> esc_html__( "Insert a valid Google Maps address", 'boc-shortcodes-and-widgets' ),
			),
			array(
				"type"			=> "textfield",
				"admin_label"	=> true,
				"heading"		=> esc_html__( "Latitude", 'boc-shortcodes-and-widgets' ),
				"param_name"	=> "lat",
				"value"			=> "",
				"std"			=> "",
				"description"	=> esc_html__( "You can use coordinates instead of the address field.", 'boc-shortcodes-and-widgets' ),
			),
			array(
				"type"			=> "textfield",
				"admin_label"	=> true,
				"heading"		=> esc_html__( "Longitude", 'boc-shortcodes-and-widgets' ),
				"param_name"	=> "lon",
				"value"			=> "",
				"std"			=> "",
				"description"	=> esc_html__( "You can use coordinates instead of the address field.", 'boc-shortcodes-and-widgets' ),
			),
			array(
				"type"			=> "textfield",
				"admin_label"	=> false,
				"heading"		=> esc_html__( "Height", 'boc-shortcodes-and-widgets' ),
				"param_name"	=> "height",
				"value"			=> "400",
				"std"			=> "400",
				"description"	=> esc_html__( "Height of the Map in px (Default is 400)", 'boc-shortcodes-and-widgets' ),
			),
			array(
				"type"			=> "textfield",
				"admin_label"	=> false,
				"heading"		=> esc_html__( "Google API Key", 'boc-shortcodes-and-widgets' ),
				"param_name"	=> "api_key",
				"value"			=> "",
				"description"	=> __( "Enter your <a href='https://developers.google.com/maps/documentation/javascript/get-api-key' target='_blank'>Google API key</a>", 'boc-shortcodes-and-widgets' ),
			),
			array(
				"type"			=> "textfield",
				"admin_label"	=> false,
				"heading"		=> esc_html__( "Zoom Level", 'boc-shortcodes-and-widgets' ),
				"param_name"	=> "zoom",
				"value"			=> "14",
				"std"			=> "14",
				"description"	=> esc_html__( "Value between 1-21. The Higher the number - the more zoomed in. (Default is 14)", 'boc-shortcodes-and-widgets' ),
				"group"			=> esc_html__( 'Options', 'boc-shortcodes-and-widgets' ),
			),
			array(
				"type"			=> "dropdown",
				"admin_label"	=> false,
				"heading"		=> esc_html__( "Map Type", 'boc-shortcodes-and-widgets' ),
				"param_name"	=> "maptype",
				"value"			=> array(
					'Roadmap' 	=> 'ROADMAP',
					'Satellite' => 'SATELLITE',
					'Hybrid' 	=> 'HYBRID',
					'Terrain' 	=> 'TERRAIN',
				),
				"description"	=> esc_html__( "Pick a map type", 'boc-shortcodes-and-widgets' ),
				"group"			=> esc_html__( 'Options', 'boc-shortcodes-and-widgets' ),
			),
			
			array(
				"type"			=> 'checkbox',
				"heading" 		=> esc_html__("Scrollwheel Zoom", 'boc-shortcodes-and-widgets'),
				"param_name" 	=> "scrollwheel",
				"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
				"description" 	=> esc_html__("Enable mouse scrollwheel zooming?", 'boc-shortcodes-and-widgets'),
				"group"			=> esc_html__( 'Options', 'boc-shortcodes-and-widgets' ),
			),				

			array(
				"type"			=> 'checkbox',
				"heading" 		=> esc_html__("Hide Map Controls?", 'boc-shortcodes-and-widgets'),
				"param_name" 	=> "hidecontrols",
				"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
				"group"			=> esc_html__( 'Options', 'boc-shortcodes-and-widgets' ),
			),				

			array(
				"type"			=> "dropdown",
				"admin_label"	=> false,
				"heading"		=> esc_html__( "Map Style", 'boc-shortcodes-and-widgets' ),
				"param_name"	=> "colorscheme",
				"value"			=> array(
					'1 Default Style' 	=> '1',
					'2 (Vivid)' 		=> '2',
					'3 (Green)' 		=> '3',
					'4 (Blue)' 			=> '4',
					'5 (Grey)' 			=> '5',
					'6 (Dark Grey)' 	=> '6',
				),
				"std"			=> "1",
				"description"	=> esc_html__( "Pick a Style for your Map", 'boc-shortcodes-and-widgets' ),
				"group"			=> esc_html__( 'Options', 'boc-shortcodes-and-widgets' ),
			),

			array(
				"type"			=> 'checkbox',
				"heading" 		=> esc_html__("Show Marker", 'boc-shortcodes-and-widgets'),
				"param_name" 	=> "marker",
				"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
				"description" 	=> esc_html__("Show a Marker on your Map?", 'boc-shortcodes-and-widgets'),
				"group"			=> esc_html__( 'Marker', 'boc-shortcodes-and-widgets' ),
			),
			array(
				"type"			=> "attach_image",
				"admin_label"	=> false,
				"heading"		=> esc_html__( "Marker Image", 'boc-shortcodes-and-widgets' ),
				"param_name"	=> "markerimage",
				"value"			=> "",
				"description"	=> esc_html__( "If you want to use a Marker Image you can upload it here.", 'boc-shortcodes-and-widgets' ),
				"group"			=> esc_html__( 'Marker', 'boc-shortcodes-and-widgets' ),
				"dependency"	=> Array( 'element'	=> "marker", 'not_empty' => true ),
			),
			array(
				"type"			=> "textarea",
				"admin_label"	=> false,
				"heading"		=> esc_html__( "Info Text", 'boc-shortcodes-and-widgets' ),
				"param_name"	=> "infowindow",
				"value"			=> "",
				"description"	=> esc_html__( "Text to add to the Infowindow", 'boc-shortcodes-and-widgets' ),
				"group"			=> esc_html__( 'Marker', 'boc-shortcodes-and-widgets' ),
				"dependency"	=> Array( 'element'	=> "marker", 'not_empty' => true ),
			),
			array(
				"type"			=> 'checkbox',
				"heading" 		=> esc_html__( "Show Info Text by default", 'boc-shortcodes-and-widgets' ),
				"param_name" 	=> "infowindowdefault",
				"value"			=> Array(esc_html__("Yes", "boc-shortcodes-and-widgets") => 'yes' ),
				"description" 	=> esc_html__("Show Info Text on Page Load?", 'boc-shortcodes-and-widgets'),
				"group"			=> esc_html__( 'Marker', 'boc-shortcodes-and-widgets' ),
				"dependency"	=> Array( 'element'	=> "infowindow", 'not_empty' => true ),
			),	
		)
	) );