<?php

//--------- OT THEME OPTIONS ------------//

// Hide unneeded sections from Import/Export Page
add_filter( 'ot_show_options_ui', '__return_false' );
add_filter( 'ot_show_settings_import', '__return_false' );
add_filter( 'ot_show_settings_export', '__return_false' );
add_filter( 'ot_show_new_layout', '__return_false' );
add_filter( 'ot_show_docs', '__return_false' );

// Run in Theme Mode
add_filter( 'ot_theme_mode', '__return_true' );

load_template( trailingslashit( get_template_directory() ) . 'includes/ext/option-tree/ot-loader.php' );
// BOC Theme Options
load_template( trailingslashit( get_template_directory() ) . 'includes/boc_theme_options.php' );

//--------- OT THEME OPTIONS :: END  ----//


//--------- Alea Specific Methods ------------//

// Alea Customizer Theme Options
load_template( trailingslashit( get_template_directory() ) . 'includes/customizer_theme-options.php' );
load_template( trailingslashit( get_template_directory() ) . 'includes/meta_boxes.php' );

// Default RSS feed links
add_theme_support('automatic-feed-links');


// Post Formats
add_theme_support( 'post-formats',  array( 'gallery','video' ));
add_post_type_support( 'post', 'post-formats' );
add_post_type_support( 'portfolio', 'post-formats' );

// Sets up the content width value based on the theme's design and stylesheet (Required by Theme Check)
if (!isset($content_width)){
	$content_width = 1200;
}

// Let WP manage title - it's removed from header.php
add_theme_support( 'title-tag' );

// Alea Customizer Theme Options
add_action( 'customize_register', 'aqua_customize_register' );


//	Alea suggested plugins
load_template( trailingslashit( get_template_directory() ) . 'includes/ext/class-tgm-plugin-activation.php');
add_action( 'tgmpa_register', 'boc_theme_register_required_plugins' );


//	Global theme specific JS params array : $boc_js_params
$boc_js_params = array();
$boc_js_params['boc_is_mobile_device'] 	= wp_is_mobile();


//	Enqueue BOC Styles
add_action( 'wp_enqueue_scripts', 'boc_styles' );
function boc_styles() {

	wp_enqueue_style( 'boc-grid', get_template_directory_uri().'/stylesheets/grid.css');
	wp_enqueue_style( 'boc-icon', get_template_directory_uri().'/stylesheets/icons.css');

	// Load custom woo CSS if plugin is active
	if ( class_exists( 'woocommerce' ) ) {
		wp_enqueue_style( 'boc-woo-styles', get_template_directory_uri().'/stylesheets/woocommerce.css');
	}

	// Main CSS + Animation CSS dependent on VC CSS if VC is active
	if(function_exists('vc_set_as_theme')){
		wp_enqueue_style( 'boc-main-styles', get_bloginfo( 'stylesheet_url' ), array('js_composer_front') );
		wp_enqueue_style( 'boc-animation-styles', get_template_directory_uri().'/stylesheets/animations.css', array('js_composer_front'));
	} else {
		wp_enqueue_style( 'boc-main-styles', get_bloginfo( 'stylesheet_url' ) );
		wp_enqueue_style( 'boc-animation-styles', get_template_directory_uri().'/stylesheets/animations.css');
	}
	
	
	// Load Responsive/NonResponsive styles
	if(ot_get_option('responsive_design','on')=='on'){
		wp_enqueue_style( 'boc-responsive-style', get_template_directory_uri().'/stylesheets/grid_responsive.css' );
	}else {
		wp_enqueue_style( 'boc-nonresponsive-style', get_template_directory_uri().'/stylesheets/non-responsive.css' );
	}

	// 	Load RTL if needed
	if (is_rtl()) {
		boc_styles_rtl();
	}

	// Attach Custom CSS to the last CSS file so one can override all CSS files
	$inline_css = boc_get_inline_CSS();
	wp_add_inline_style( 'boc-animation-styles', $inline_css );
}

// 	RTL styles
function boc_styles_rtl() {

	wp_enqueue_style( 'boc-grid-rtl', get_template_directory_uri().'/stylesheets/rtl-grid.css');

	// Load custom woo CSS if plugin is active
	if ( class_exists( 'woocommerce' ) ) {
		wp_enqueue_style( 'boc-woo-styles-rtl', get_template_directory_uri().'/stylesheets/rtl-woocommerce.css');
	}

	// Load Main CSS
	wp_enqueue_style( 'boc-main-styles-rtl', get_template_directory_uri().'/stylesheets/rtl-style.css');

	// Animations CSS - with a dependency, load it after VC Css to overwrite the animations
	wp_enqueue_style( 'boc-animation-styles', get_template_directory_uri().'/stylesheets/rtl-animations.css', array('js_composer_front'));

	if(ot_get_option('responsive_design','on')=='on'){
		wp_enqueue_style( 'boc-responsive-style-rtl', get_template_directory_uri().'/stylesheets/rtl-grid_responsive.css' );
	}else {
		wp_enqueue_style( 'boc-nonresponsive-style-rtl', get_template_directory_uri().'/stylesheets/rtl-non-responsive.css' );
	}
}


// Register Default Google Fonts
function boc_fonts_url() {
    $font_url = '';

    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
    */
    if ( 'off' !== _x( 'on', 'Default Google Fonts: on or off', 'alea' ) ) {
        $font_url = add_query_arg( 'family', urlencode('Open Sans:400,600|Montserrat:300,400,500,600'), "//fonts.googleapis.com/css" );
    }
    return $font_url;
}

// Enqueue Default Google Fonts
function boc_add_default_fonts() {
    wp_enqueue_style( 'boc-fonts', boc_fonts_url(), array(), '1.0.0' );
}
add_action( 'wp_enqueue_scripts', 'boc_add_default_fonts' );



// Enqueue Scripts
add_action( 'wp_enqueue_scripts', 'boc_scripts' );
function boc_scripts() {
	
	if ((is_single() && comments_open()) || (is_page() && comments_open() && (ot_get_option('show_page_comments', 'on') == 'on'))) {
      wp_enqueue_script('comment-reply');
    }
	
	global $boc_js_params;

	$boc_js_params['boc_submenu_animation_effect'] = ot_get_option('submenu_animation_effect', 'sub_fade_in');

	// Set Retina Logos
	$boc_js_params['retina_logo_url'] = ot_get_option('logo_upload_retina','');
	$boc_js_params['mobile_retina_logo_url'] = ot_get_option('mobile_logo_upload_retina','');
	$boc_js_params['retina_logo_transparent_url'] = ot_get_option('logo_transparent_upload_retina','');

	// External Libs
	wp_enqueue_script('superfish', get_template_directory_uri().'/js/superfish.js', array('jquery'));
	wp_enqueue_script('jquery-easing', get_template_directory_uri().'/js/jquery.easing.js', array('jquery'));
	wp_enqueue_script('isotope', get_template_directory_uri().'/js/isotope.js', array('jquery'));
	wp_enqueue_script('waypoints', get_template_directory_uri().'/js/waypoints.js', array('jquery'));
	wp_enqueue_script('magnific-popup', get_template_directory_uri().'/js/jquery.magnific-popup.js', array('jquery'));
	wp_enqueue_script('owl-carousel', get_template_directory_uri().'/js/owl.carousel.js', array('jquery'));
	wp_enqueue_script('boc-counters', get_template_directory_uri().'/js/boc.counters.js', array('jquery'));
	wp_enqueue_script('smoothscroll', get_template_directory_uri().'/js/smoothscroll.js', array('jquery'));
	wp_enqueue_script('gumshoe', get_template_directory_uri().'/js/gumshoe.js', array('jquery'));
	wp_enqueue_script('tipsy', get_template_directory_uri().'/js/tipsy.js', array('jquery'));
	wp_enqueue_script('easy-tabs', get_template_directory_uri().'/js/easy.tabs.js', array('jquery'));
	wp_enqueue_script('typed', get_template_directory_uri().'/js/typed.js', array('jquery'));

	// Theme Specific JS
	wp_enqueue_script('alea-common', get_template_directory_uri().'/js/common.js');
	wp_localize_script('alea-common', 'bocJSParams', $boc_js_params );
	
	// Register handles for Inline JS that will late-load 
	wp_register_script( 'boc-theme-inline-scripts', false, array('alea-common') );

	// Smooth Scrolling
	if(ot_get_option('smooth_scrolling','off') == 'on'){
		wp_enqueue_script('wheel-smoothscroll', get_template_directory_uri().'/js/wheel-smoothscroll.js');
	}	
	
	// Load RTL scripts if needed
	if (is_rtl()) {
		wp_enqueue_script('alea-common-rtl', get_template_directory_uri().'/js/rtl-common.js');
	}
}


// Include Core Theme Functions + Widgets
load_template( trailingslashit( get_template_directory() ) . 'includes/boc_theme_options_methods.php' );
load_template( trailingslashit( get_template_directory() ) . 'includes/boc_framework.php' );

// Make theme available for translation
load_theme_textdomain( 'alea', get_template_directory() . '/languages' );


// Load WP Comment Reply JS script
if(is_singular()){
	wp_enqueue_script( 'comment-reply' );
}

// Trim the excerpt 
function boc_excerpt_more($more) {
	global $post;
	return '...';
}
add_filter('excerpt_more', 'boc_excerpt_more');


// Main Alea Startup
add_action('init', 'boc_alea_init');

function boc_alea_init(){
	boc_add_thumbs();
	boc_register_menus();
	boc_register_widgets();
}

// Add custom thumbs
if ( !function_exists( 'boc_add_thumbs' ) ) {
	function boc_add_thumbs(){
		add_theme_support('post-thumbnails');
		add_image_size('boc_thumb', 150, 150, true);
		add_image_size('boc_medium', 600, 400, true);
		add_image_size('boc_thin', 1200, 600, true);
	}
}

// Register Menus
if ( !function_exists( 'boc_register_menus' ) ) {
	function boc_register_menus(){
		register_nav_menus( array(
			'main_navigation' => esc_html__( 'Main Navigation', 'alea' ),
			'subheader_navigation' => esc_html__( 'Sub-Header Menu', 'alea' )
		));
	}
}

// Register Widget Areas
add_action('widgets_init', 'boc_register_widgets');
if ( !function_exists( 'boc_register_widgets' ) ) {
	function boc_register_widgets(){

		if(function_exists('register_sidebar')) {

			// Register Dynamic Widgets (OT)
			if (ot_get_option('boc_sidebars')){
				$dynamic_sidebars = ot_get_option('boc_sidebars');
				foreach ($dynamic_sidebars as $dynamic_sidebar) {
					register_sidebar(array(
						'name' => $dynamic_sidebar["title"],
						'id' => $dynamic_sidebar["id"],
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h4 class="boc_heading bgr_dotted"><span>',
						'after_title' => '</span></h4>',
						));
				}
			}

			// Register widgetized locations
			register_sidebar(array(
				'name' => esc_html__( 'Alea Default Sidebar', 'alea' ),
				'id'   => 'alea_default_sidebar',
				'description'   => esc_html__( 'Widgets in this area will be shown on your default Blog page.', 'alea' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h4 class="boc_heading bgr_dotted"><span>',
				'after_title' => '</span></h4>',
			));
			register_sidebar(array(
				'name' => esc_html__( 'Footer Column 1', 'alea' ),
				'id'   => 'alea_footer_widget1',
				'description'   => esc_html__( 'Widgets in this area will be shown in the First Column of the Footer', 'alea' ),
				'before_widget' => '',
				'after_widget' => '',
				'before_title' => '<h3>',
				'after_title' => '</h3>',
			));
			register_sidebar(array(
				'name' => esc_html__( 'Footer Column 2', 'alea' ),
				'id'   => 'alea_footer_widget2',
				'description'   => esc_html__( 'Widgets in this area will be shown in the Second Column of the Footer', 'alea' ),
				'before_widget' => '',
				'after_widget' => '',
				'before_title' => '<h3>',
				'after_title' => '</h3>',
			));
			register_sidebar(array(
				'name' => esc_html__( 'Footer Column 3', 'alea' ),
				'id'   => 'alea_footer_widget3',
				'description'   => esc_html__( 'Widgets in this area will be shown in the Third Column of the Footer', 'alea' ),
				'before_widget' => '',
				'after_widget' => '',
				'before_title' => '<h3>',
				'after_title' => '</h3>',
			));
			register_sidebar(array(
				'name' => esc_html__( 'Footer Column 4', 'alea' ),
				'id'   => 'alea_footer_widget4',
				'description'   => esc_html__( 'Widgets in this area will be shown in the Fourth Column of the Footer', 'alea' ),
				'before_widget' => '',
				'after_widget' => '',
				'before_title' => '<h3>',
				'after_title' => '</h3>',
			));
			register_sidebar(array(
				'name' => esc_html__( 'Search Page Sidebar', 'alea' ),
				'id'   => 'search_page_sidebar',
				'description'   => esc_html__( 'Widgets in this area will be shown in the Search Page', 'alea' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h3>',
				'after_title' => '</h3>',
			));
			register_sidebar(array(
				'name' => esc_html__( 'Contact Sidebar', 'alea' ),
				'id'   => 'contact_sidebar',
				'description'   => esc_html__( 'Widgets in this area will be shown on custom Contact Pages', 'alea' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h3>',
				'after_title' => '</h3>',
			));
			register_sidebar(array(
				'name' => esc_html__( 'WooCommerce Sidebar', 'alea' ),
				'id'   => 'alea_woocommerce_sidebar',
				'description'   => esc_html__( 'Widgets in this area will be shown on WooCommerce Shop Pages', 'alea' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h4 class="boc_heading bgr_dotted"><span>',
				'after_title' => '</span></h4>',
			));
			register_sidebar(array(
				'name' => esc_html__( 'WooCommerce Product Page Sidebar', 'alea' ),
				'id'   => 'alea_woocommerce_product_sidebar',
				'description'   => esc_html__( 'Widgets in this area will be shown on WooCommerce Product Pages', 'alea' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h4 class="boc_heading bgr_dotted"><span>',
				'after_title' => '</span></h4>',
			));

			// Subheader Widget
			register_sidebar(array(
				'name' => esc_html__( 'Subheader Widget Area', 'alea' ),
				'id'   => 'alea_subheader_widget_area',
				'description'   => esc_html__( 'Widgets in this area will be shown in your header above the Main Menu', 'alea' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h4 class="boc_heading"><span>',
				'after_title' => '</span></h4>',
			));

			// Header Icons Widget
			register_sidebar(array(
				'name' => esc_html__( 'Header Icons Widget Area', 'alea' ),
				'id'   => 'alea_header_icons_widget_area',
				'description'   => esc_html__( 'Widgets in this area will be shown in your header above the Main Menu when using Stripe and Solid Navigation Styles in Theme Options', 'alea' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h4 class="boc_heading"><span>',
				'after_title' => '</span></h4>',
			));

			// Side Menu Widget
			register_sidebar(array(
				'name' => esc_html__( 'Side FlyOut Widget Area', 'alea' ),
				'id'   => 'alea_side_widget_area',
				'description'   => esc_html__( 'Widgets in this area will be shown when hamburger Menu in the top right of the header gets clicked', 'alea' ),
				'before_widget' => '<div id="%1$s" class="boc_side_widget_content widget white_links %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h4 class="boc_heading"><span>',
				'after_title' => '</span></h4>',
			));

		}
	}
}


// Customize Tag Cloud
function boc_tag_cloud_args($args){
    $args['largest'] = 14;
	$args['smallest'] = 14;
	$args['unit'] = 'px';
	$args['orderby'] = 'name';
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'boc_tag_cloud_args');


///////////////////////////////////////////
// --------   Visual Composer  --------- //
///////////////////////////////////////////

if(function_exists('vc_set_as_theme')){

	add_action( 'vc_before_init', 'boc_setup_VC_in_theme', 10);

	function boc_setup_VC_in_theme(){
		
		vc_set_as_theme(true);
		
		// Disable front end editor
		if (ot_get_option('boc_disable_vc_frontend_editor','on')=='on') {
			vc_disable_frontend();
		}

	}
}

///////////////////////////////////////////
// ----------   Rev Slider   ----------- //
///////////////////////////////////////////

// Disable the notification for activation
if ( is_admin() ) {
	if(function_exists( 'set_revslider_as_theme' )){
		add_action( 'init', 'boc_set_Rev_Slider_as_theme' );
		function boc_set_Rev_Slider_as_theme() {
			update_option('revslider-valid-notice', 'false');
			set_revslider_as_theme();
		}
	}
}

///////////////////////////////////////////
// ----------   WooCommerce  ----------- //
///////////////////////////////////////////

add_theme_support( 'woocommerce' );
// IF woocommerce is activated
if ( class_exists( 'woocommerce' ) ) {
	
	add_action( 'woocommerce_init', 'boc_woocommerce_init', 10, 1 ); 
	
	function boc_woocommerce_init(){
		
		wp_enqueue_script('alea-woo-plus-minus',get_template_directory_uri().'/js/woo-plus-minus.js', array('jquery'));
		
		// Add woocommerce class to body as it's been removed since 3.4 update
		add_filter('body_class', 'boc_add_woo_body_class');
		function boc_add_woo_body_class($classes) {
			if (is_woocommerce()) {
				$classes[] = 'woocommerce';
			}
			return $classes;
		}	
		
		// IF lightbox is enabled in admin we shall enable the custom one
		$boc_js_params['boc_woo_lightbox_enabled'] = 1;

		// Remove Page Title
		add_filter( 'woocommerce_show_page_title', 'boc_remove_woo_shop_title');
		// Remove woo page title from shop
		if ( !function_exists( 'boc_remove_woo_shop_title' ) ) {
			function boc_remove_woo_shop_title() {
				if (function_exists('is_shop') && is_shop() && is_singular('product') ) {
					return false;
				}
			}
		}

		function boc_close_div() {
			echo '</div>';
		}

		//wrap single product image in an extra div
		add_action( 'woocommerce_before_single_product_summary', 'boc_images_div', 2);
		add_action( 'woocommerce_before_single_product_summary',  'boc_close_div', 20);
		function boc_images_div()
		{
			echo "<div class='col span_5 single_product_left'>";
		}

		//wrap product description
		add_action('woocommerce_before_single_product_summary', 'boc_summary_div', 35);
		add_action('woocommerce_after_single_product_summary',  'boc_close_div', 4);
		function boc_summary_div() {
			echo "<div class='col span_7 single_product_right'>";
		}

		//change tab position to be inside summary
		remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10);
		add_action('woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 1);


		// Show upsells and related products
		remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_related_products',20);
		remove_action('woocommerce_after_single_product', 'woocommerce_output_related_products',10);


		remove_action('woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15);
		remove_action('woocommerce_after_single_product', 'woocommerce_upsell_display',10);
		add_action('woocommerce_after_single_product_summary', 'boc_woocommerce_output_upsells', 21);

		function boc_woocommerce_output_upsells() {

			$output = null;

			ob_start();
			woocommerce_upsell_display(4,4);
			$content = ob_get_clean();
			if($content) { $output .= $content; }

			echo wp_kses_post($output);
		}

		// Custom Cart in Header
		add_filter('woocommerce_add_to_cart_fragments', 'boc_woocommerce_header_add_to_cart_fragment');
		function boc_woocommerce_header_add_to_cart_fragment( $fragments ) {
			global $woocommerce;

			ob_start(); 
			$link = function_exists( 'wc_get_cart_url' ) ? wc_get_cart_url() : $woocommerce->cart->get_cart_url();
			?>

			<a class="cart-contents header_cart_icon boc_i-cart2" href="<?php echo esc_url($link); ?>">
				<p class="cart-wrap"><span><?php echo (int)$woocommerce->cart->cart_contents_count; ?></span></p>
			</a>

			<?php
			$fragments['a.cart-contents'] = ob_get_clean();

			return $fragments;
		}


		add_action( 'woocommerce_before_single_product', 'boc_wrap_single_product_image', 8);
		add_action( 'woocommerce_after_single_product', 'boc_close_div', 9);

		function boc_wrap_single_product_image() {

			echo "<div class='boc_single_product'>";
		}


		// Set products per page as defined in OT
		add_filter( 'loop_shop_per_page', 'boc_products_per_page', 20 );
		function boc_products_per_page() {
			return ot_get_option('woocommerce_products_per_page','12');
		}

		// Add 'dark_links' class wrapper div to product loop items
		add_action('woocommerce_before_shop_loop_item','boc_product_item_dark_link_open',8);
		add_action('woocommerce_after_shop_loop_item','boc_close_div',9);
		function boc_product_item_dark_link_open(){
			echo '<div class="dark_links">';
		}
		
		// Change Pagination Arrows
		add_filter( 'woocommerce_pagination_args', 	'boc_woo_pagination' );
		function boc_woo_pagination( $args ) {
			$left 	= 'left';
			$right 	= 'right';
			if(is_rtl()) {
				$left 	= 'right';
				$right 	= 'left';
			}
			$args['prev_text'] = '<span class="boc_i-arrow-point-to-'.$left.'"></span>';
			$args['next_text'] = '<span class="boc_i-arrow-point-to-'.$right.'"></span>';
			return $args;
		}
	}
}


////////////////////////////////////////////////////
// ----------   One Click Demo Import ----------- //
////////////////////////////////////////////////////
if (is_admin() && class_exists('OCDI_Plugin')) {
    load_template( trailingslashit( get_template_directory() ) . 'includes/boc_oc_import_demo.php' );
}

function remove_menus(){   
  remove_menu_page( 'edit-comments.php' );          //Comments  
}  
add_action( 'admin_menu', 'remove_menus' );  
?>