<?php
///////////////////////////////////////////
//---- OT THEME SPECIFIC OPTIONS --------//
///////////////////////////////////////////


/**
 * Initialize the options before anything else.
 */
add_action('admin_init', 'boc_custom_theme_options', 1);


//  Add Theme Specific Fonts to Default Font list
add_filter('ot_recognized_font_families', 'boc_custom_fonts_add', 1, 3);
function boc_custom_fonts_add($families, $field_id) {
    $families = array_merge($families,
        array(
            'montserrat'=> 'Montserrat',
            'opensans' 	=> 'Open Sans',
        )
    );
    return $families;
}

//	Filter Out Some Typography Option Fields
add_filter('ot_recognized_typography_fields', 'boc_filter_typography_fields', 10, 2);
function boc_filter_typography_fields($array, $field_id) {

    if ($field_id == 'nav_font') {
        $array = array('font-family', 'font-size', 'font-weight', 'letter-spacing', 'text-transform');
    } elseif ($field_id == 'sub_nav_font') {
        $array = array('font-family', 'font-size', 'font-weight', 'letter-spacing', 'text-transform');
    } elseif ($field_id == 'heading_font') {
        $array = array('font-family', 'font-weight', 'letter-spacing', 'text-transform');
    } elseif ($field_id == 'body_font') {
        $array = array('font-family', 'font-size', 'font-weight');
    } elseif ($field_id == 'button_font') {
        $array = array('font-family', 'letter-spacing', 'font-weight', 'text-transform');
    }
    return $array;
}

//	Change default OT Upload text
add_filter('ot_upload_text', 'boc_ot_upload_text', 10, 2);
function boc_ot_upload_text($txt) {
    return 'Upload';
}


/**
 * BOC Custom types.
 */
function boc_custom_theme_options() {

    /**
     * Get a copy of the saved settings array.
     */
    $saved_settings = get_option('option_tree_settings', array());


    /**
     * Create a custom settings array that we pass to
     * the OptionTree Settings API Class.
     */

    $custom_settings = array(
        'sections' => array(
            array(
                'title' => '<span class="ot-icon-desktop"></span> Header',
                'id' => 'header',
            ),
            array(
                'title' => '<span class="ot-icon-font"></span>Typography',
                'id' => 'typography'
            ),
            array(
                'id' => 'general',
                'title' => '<span class="ot-icon-gear"></span> General'
            ),
            array(
                'id' => 'footer',
                'title' => '<span class="ot-icon-desktop"></span> Footer'
            ),
            array(
                'id' => 'portfolio',
                'title' => '<span class="ot-icon-briefcase"></span> Portfolio'
            ),
            array(
                'id' => 'blog',
                'title' => '<span class="ot-icon-th-list"></span> Blog'
            ),
            array(
                'id' => 'sidebars',
                'title' => '<span class="ot-icon-columns"></span> Sidebars'
            ),
            array(
                'id' => 'woocommerce',
                'title' => '<span class="ot-icon-tag"></span> WooCommerce'
            ),
            array(
                'id' => 'custom_styles',
                'title' => '<span class="ot-icon-code"></span> Custom CSS'
            ),
        ),
        'settings' => array(

            array(
                'id' => 'tab_Main',
                'label' => 'Main',
                'type' => 'tab',
                'section' => 'header'
            ),

            array(
                'label' => 'Upload Main Logo',
                'id' => 'logo_upload',
                'type' => 'upload',
                'desc' => 'Upload your Logo here. Our sample logo is 117x50, if yours is much different in size and looks way off, you can use the header height options below to change its default margins.',
				'class'   => 'ot-upload-attachment-id hidden_field',
                'section' => 'header',
            ),
            array(
                'label' => 'Upload Main Retina Logo (optional)',
                'id' => 'logo_upload_retina',
                'type' => 'upload',
                'desc' => 'Upload a Retina Logo version here if you want to override your default logo for Retina screens (only if your default one looks blurry on high resolution screens). Make sure it is double the size of the regular Logo, for example if your logo is 200x50 your Retina logo should be 400x100.',
				'class'   => 'hidden_field',
                'section' => 'header',
            ),
			
            array(
                'label' => 'Upload Favicon',
                'id' => 'favicon_uploaded',
                'type' => 'upload',
                'desc' => 'Upload a favicon image (16x16)',
                'section' => 'header',
            ),

            array(
                'label' => 'Header Height',
                'id' => 'header_height',
                'desc' => 'Change your Heager Height in <strong>px</strong>. Default value is <strong>92px</strong>',
                'std' => '92',
                'type' => 'numeric-slider',
                'section' => 'header',
                'min_max_step' => '50,150,1'
            ),


            array(
                'label' => 'Header Background Color',
                'id' => 'header_bgr_color',
                'type' => 'colorpicker',
                'desc' => 'Change your Header Background Color (Solid color Hex Value)',
                'section' => 'header',
                'std' => '#ffffff',
            ),

            array(
                'label' => 'Header Width',
                'id' => 'header_width',
                'type' => 'select',
                'desc' => 'Should your header stretch to screen full width or only to the content wrapper width',
                'section' => 'header',
                'choices' => array(
                    array(
                        'label' => 'Wrapper Width',
                        'value' => '0'
                    ),
                    array(
                        'label' => 'Full Width',
                        'value' => '1'
                    )
                ),
                'std' => '0',
            ),


            array(
                'id' => 'tab_main_navigation',
                'label' => 'Main Navigation',
                'type' => 'tab',
                'section' => 'header',
            ),


            array(
                'label' => 'Navigation Style',
                'id' => 'navigation_style',
                'type' => 'radio-image',
                'desc' => 'Choose your Header Navigation Style. According to the style you pick the options below this selection will vary. Some of the Navigation styles only disregard/override other settings as they are not applicable. For example the Angular Navigation style negates the settings for Header height and Sticky header height.',
                'std' => 'menu_regular_style',
                'section' => 'header',
                'choices' => array(
                    array(
                        'value' => 'menu_regular_style',
                        'label' => 'Regular Style',
                        'src' => OT_URL . '../ot_images/menu_regular.png'
                    ),
                    array(
                        'value' => 'menu_stripe_style',
                        'label' => 'Stripe Style',
                        'src' => OT_URL . '../ot_images/menu_striped.png'
                    ),
                    array(
                        'value' => 'menu_solid_style',
                        'label' => 'Solid Style',
                        'src' => OT_URL . '../ot_images/menu_solid.png'
                    ),
                    array(
                        'value' => 'menu_angular_style',
                        'label' => 'Angular Style',
                        'src' => OT_URL . '../ot_images/menu_angular.png'
                    ),
                    array(
                        'value' => 'menu_regular_style menu_midlogo',
                        'label' => 'Mid Logo Regular',
                        'src' => OT_URL . '../ot_images/menu_midlogo.png'
                    ),
                    array(
                        'value' => 'menu_regular_style menu_toplogo',
                        'label' => 'Top Logo Regular',
                        'src' => OT_URL . '../ot_images/menu_toplogo.png'
                    ),
                ),
            ),


            array(
                'label' => 'Hide logo on scroll for Top Logo Menu style',
                'id' => 'nav_hide_logo_on_scroll',
                'type' => 'select',
                'desc' => 'Change to Yes if you want the Logo to hide when scrolling down (only for Top Logo menu style). ',
                'choices' => array(
                    array(
                        'label' => 'No',
                        'value' => 0
                    ),
					 array(
                        'label' => 'Yes',
                        'value' => 1
                    )
                ),
                'std' => 0,
                'section' => 'header',
                'condition' => "navigation_style:is(menu_regular_style menu_toplogo)",
            ),			
			
			
            array(
                'label' => 'Full Width Menu bar? (Stripe Style only)',
                'id' => 'full_width_stripe_menu',
                'desc' => 'You can choose "On" if you want your Stripe Style menu to be full width',
                'type' => 'on_off',
                'std' => 'off',
                'section' => 'header',
                'condition' => "navigation_style:is(menu_stripe_style)",
            ),


            array(
                'label' => 'Stripe Menu Background Style? (Stripe Style only)',
                'id' => 'stripe_menu_background',
                'type' => 'select',
                'desc' => 'You can further customize the Stripe Style menu with simple CSS.',
                'choices' => array(
                    array(
                        'label' => 'Black',
                        'value' => 'black'
                    ),
                    array(
                        'label' => 'White',
                        'value' => 'white'
                    )
                ),
                'std' => 'black',
                'section' => 'header',
                'condition' => "navigation_style:is(menu_stripe_style)",
            ),
			
			

            array(
                'label' => 'Main Navigation Alignment',
                'id' => 'menu_alignment',
                'type' => 'select',
                'desc' => 'Pick where you want your menu aligned',
                'choices' => array(
                    array(
                        'label' => 'Left',
                        'value' => 'al_left'
                    ),
                    array(
                        'label' => 'Center',
                        'value' => 'centered'
                    ),
                    array(
                        'label' => 'Right',
                        'value' => 'al_right_menu'
                    )
                ),
                'std' => 'centered',
                'condition' => "nav_top_block_style:is(0),navigation_style:is(menu_regular_style)",
                'section' => 'header',
            ),			
			
			
            array(
                'label' => 'Header Text Color',
                'id' => 'main_navigation_color',
                'type' => 'colorpicker',
                'desc' => 'Overwrite Main Navigation color for the <strong>Regular Style</strong>, <strong>Solid Style</strong> & <strong>Angular Style</strong> menu. Overwrite "Header text & icon" color for the <strong>Stripe Style</strong> & <strong>Solid Style</strong> menu.',
                'section' => 'header',
                'std' => '#333333',
            ),
            array(
                'label' => 'Header Hover Text Color',
                'id' => 'main_navigation_hover_color',
                'type' => 'colorpicker',
                'desc' => 'Overwrite Main Navigation Hover color for the <strong>Regular Style</strong>, <strong>Solid Style</strong> & <strong>Angular Style</strong> menu. Overwrite "Header links" Hover color for the <strong>Stripe Style</strong> & <strong>Solid Style</strong> menu.',
                'section' => 'header',
                'std' => '#333333',
            ),
			
			
            array(
                'label' => 'Header Striped Navigation Hover BGR Color',
                'id' => 'striped_main_navigation_hover_color',
                'type' => 'colorpicker',
                'desc' => 'Overwrite Striped Main Navigation Hover Background color for the <strong>Stripe Style</strong>',
                'section' => 'header',
                'std' => '#0bafc7',
				'condition' => "navigation_style:is(menu_stripe_style)",
            ),		
			
            array(
                'label' => 'Logo Section Background Color (Angular Menu only)',
                'id' => 'angular_main_navigation_logo_background',
                'type' => 'colorpicker',
                'desc' => 'Overwrite Logo section background color for the <strong>Angular Menu</strong>',
                'section' => 'header',
                'std' => '#ffffff',
				'condition' => "navigation_style:is(menu_angular_style)",
            ),

		
	
			array(
			  'label'       => 'Main Navigation Animated Underline Effect',
			  'id'          => 'main_nav_underline_effect',
			  'type'        => 'on_off',
			  'desc'        => 'Animates an underline effect when hovering top level Main Navigation items that do not have a submenu. (Applicable for all Main Navigation styles but the Stripe Style)',
			  'std'         => 'on',
			  'section'     => 'header',
			  'condition' 	=> "navigation_style:not(menu_stripe_style)",
			),
			array(
			  'label'       => 'Main Navigation Animated Underline Effect Color',
			  'id'          => 'main_nav_underline_effect_color',
			  'type'        => 'colorpicker',
			  'section'     => 'header',
			  'std'         => boc_get_main_color(),
			  'condition'	=> "main_nav_underline_effect:is(on),navigation_style:not(menu_stripe_style)",	 
			),			
			
			
            array(
                'label' => 'Search Field in the Header',
                'id' => 'show_search',
                'desc' => 'You can choose "Off" if you want to hide the Search Field in the Header',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'header',
            ),
            array(
                'label' => 'Search Field Separator',
                'id' => 'show_search_separator',
                'desc' => 'You can choose "Off" if you want to hide the Search Field Separator in the header',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'header',
                'condition' => "show_search:is(on)",
            ),

            array(
                'id' => 'tab_submenu',
                'label' => 'Submenu Style',
                'type' => 'tab',
                'section' => 'header'
            ),


            array(
                'label' => 'SubMenu/Dropdown Appear Animation Effect',
                'id' => 'submenu_animation_effect',
                'type' => 'select',
                'desc' => 'Pick how the submenu should appear',
                'choices' => array(
                    array(
                        'label' => 'Fade In',
                        'value' => 'sub_fade_in'
                    ),
                    array(
                        'label' => 'Slide Down',
                        'value' => 'sub_slide_down'
                    )
                ),
                'section' => 'header',
            ),
			
            array(
                'label' => 'SubMenu/Dropdown Background Style',
                'id' => 'submenu_style',
                'type' => 'select',
                'desc' => 'Pick your Submenu background style',
                'choices' => array(
                    array(
                        'label' => 'Black',
                        'value' => 'sub_black'
                    ),
                    array(
                        'label' => 'White',
                        'value' => 'sub_white'
                    )
                ),
                'section' => 'header',
            ),
			
            array(
                'label' => 'SubMenu/Dropdown Item Style',
                'id' => 'submenu_item_style',
                'type' => 'select',
                'desc' => 'Pick your Submenu Item style',
                'choices' => array(
                    array(
                        'label' => 'Simple',
                        'value' => 'sub_simple'
                    ),
                    array(
                        'label' => 'Bordered Items',
                        'value' => 'sub_bordered'
                    )
                ),
                'section' => 'header',
            ),


            array(
                'label' => 'SubMenu Item Hover Style',
                'id' => 'submenu_item_hover_style',
                'type' => 'select',
                'desc' => 'Pick whether you want your submenu item to change background when hovered',
                'choices' => array(
                    array(
                        'label' => 'Change Background Color',
                        'value' => 'submenu_bgr_swap'
                    ),
                    array(
                        'label' => 'Minimal',
                        'value' => 'submenu_minimal'
                    )
                ),
				'std' => 'submenu_minimal',
                'section' => 'header',
            ),			
			
            array(
                'label' => 'SubMenu Item Hover Text Indent Animation',
                'id' => 'submenu_item_hover_indent',
                'type' => 'on_off',
                'desc' => 'Set to ON if you want your submenu item text to animate on hover',
                'std' => 'on',
                'section' => 'header',
            ),	
			
            array(
                'label' => 'SubMenu Item Hover Color',
                'id' => 'submenu_item_hover_color',
                'type' => 'colorpicker',
                'desc' => 'Change your SubMenu Item Hover Color (Default is #0bafc7)',
                'section' => 'header',
                'std' => '#0bafc7',
                'section' => 'header',
				'condition' => "submenu_item_hover_style:is(submenu_bgr_swap)",
            ),


            array(
                'label' => 'SubMenu/Dropdown Top border',
                'id' => 'submenu_top_border',
                'type' => 'on_off',
                'desc' => 'Set to ON if you want your submenu to have a top border',
                'std' => 'on',
                'section' => 'header',
            ),
            array(
                'label' => 'SubMenu/Dropdown Top border Color',
                'id' => 'submenu_top_border_color',
                'type' => 'colorpicker',
                'desc' => 'Change your SubMenu Top border Color (Default is #0bafc7)',
                'section' => 'header',
                'std' => '#0bafc7',
                'section' => 'header',
                'condition' => "submenu_top_border:is(on)",
            ),


            array(
                'label' => 'Mega Menu Bordered Columns',
                'id' => 'mm_bordered_columns',
                'type' => 'on_off',
                'desc' => 'Have a divider border between columns in your megamenu dropdown',
                'std' => 'on',
                'section' => 'header',
            ),			
			
            array(
                'id' => 'tab_sticky_header',
                'label' => 'Sticky header',
                'type' => 'tab',
                'section' => 'header'
            ),

            array(
                'label' => 'Sticky Header',
                'id' => 'sticky_header',
                'type' => 'on_off',
                'desc' => 'Set to OFF if you want a normal header that doesn\'t stay fixed at the top of the browser when a user scrolls down.',
                'std' => 'on',
                'section' => 'header',
            ),

            array(
                'label' => 'Sticky Header Height',
                'id' => 'sticky_header_height',
                'desc' => 'Change your Sticky Heager Height in <strong>px</strong>. Once a user scrolls down and the sticky header will resize to this height. Default value is <strong>64px</strong>.',
                'std' => '64',
                'type' => 'numeric-slider',
                'section' => 'header',
                'min_max_step' => '40,100,1',
                'condition' => "sticky_header:is(on)",
            ),

/*
            array(
                'label' => 'Sticky Header Background Color',
                'id' => 'sticky_header_color',
                'type' => 'colorpicker',
                'desc' => 'Change your Sticky Header Background Color when a user has scrolled down',
                'section' => 'header',
                'std' => '#ffffff',
                'condition' => "sticky_header:is(on)",
            ),
  */          array(
                'label' => 'Sticky Header Opacity',
                'id' => 'sticky_header_opacity',
                'desc' => 'Set your Sticky Header Opacity',
                'std' => '0.97',
                'type' => 'numeric-slider',
                'section' => 'header',
                'min_max_step' => '0.5,1,0.01',
                'condition' => "sticky_header:is(on)",
            ),
            array(
                'label' => 'Show only Navigation for Sticky Header (STRIPE MENU STYLE only)',
                'id' => 'only_nav_sticky_header',
                'type' => 'on_off',
                'desc' => 'Set to ON if you want only the Navigation to be sticky <strong>(Only available for the STRIPE MENU STYLE)</strong>.',
                'std' => 'off',
                'section' => 'header',
                'condition' => "sticky_header:is(on)",
            ),
            array(
                'id' => 'tab_subheader',
                'label' => 'Subheader',
                'type' => 'tab',
                'section' => 'header'
            ),
            array(
                'label' => 'Subheader Section above Header',
                'id' => 'subheader',
                'type' => 'on_off',
                'std' => 'off',
                'desc' => 'Show the top subheader section within your header where you can add additional contact info, an extra menu etc.',
                'section' => 'header',
            ),
            array(
                'label' => 'SubHeader Background Color',
                'id' => 'subheader_bgr_color',
                'type' => 'colorpicker-opacity',
                'desc' => 'Change your SubHeader Background Color',
                'section' => 'header',
                'std' => '#e9f3fc',
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),
            array(
                'label' => 'SubHeader Text Color',
                'id' => 'subheader_text_color',
                'type' => 'colorpicker',
                'desc' => 'Change your SubHeader Text Color',
                'section' => 'header',
                'std' => '#ffffff',
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),
            array(
                'label' => 'Hide Subheader on Scroll for Sticky Header',
                'id' => 'hide_subheader_on_scroll',
                'type' => 'on_off',
                'std' => 'on',
                'desc' => 'When a user scrolls down and the Sticky Header is activated the Subheader will hide',
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),
            array(
                'label' => 'SubHeader Address',
                'id' => 'header_address',
                'type' => 'text',
                'desc' => 'Enter your Address if you want it to appear in the theme header',
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),
            array(
                'label' => 'SubHeader Working Hours',
                'id' => 'header_hours',
                'type' => 'text',
                'desc' => 'Enter your Working Hours if you want it to appear in the theme header',
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),
            array(
                'label' => 'SubHeader Contact Email',
                'id' => 'header_email',
                'type' => 'text',
                'desc' => 'Enter your Email if you want it to appear in the theme header',
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),
            array(
                'label' => 'SubHeader Contact Phone',
                'id' => 'header_phone',
                'type' => 'text',
                'desc' => 'Enter your Phone Number if you want it to appear in the theme header',
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),


            array(
                'label' => 'Override subheader color with Theme Color for Contact Icons',
                'id' => 'subheader_contact_icons_color_override',
                'type' => 'on_off',
                'std' => 'off',
                'desc' => 'Have your contact icons (address, working hours, phone, email) inherit your Main Theme Color instead of the subheader color',
                'section' => 'header',
            ),

            array(
                'label' => 'SubHeader contacts position',
                'id' => 'header_contacts_position_is_left',
                'type' => 'select',
                'desc' => 'Align the contact details (respectively the Social icons) in your subheader (phone number/email) left or right. <strong>It is inverted in RTL mode!</strong>',
                'choices' => array(
                    array(
                        'label' => 'Left',
                        'value' => 1
                    ),
                    array(
                        'label' => 'Right',
                        'value' => 0
                    )
                ),
                'std' => 1,
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),

            array(
                'label' => 'Show Subheader Contact details in Mobile Menu',
                'id' => 'subheader_contacts_show_in_mobile',
                'type' => 'on_off',
                'std' => 'on',
                'desc' => 'Have your subheader contact details display at the bottom of your Mobile Menu',
                'section' => 'header',
            ),

            array(
                'label' => 'Header Social Icons',
                'id' => 'header_icons',
                'type' => 'list-item',
                'desc' => 'Manage your Socials Icons in the theme header. For Skype use "callto://YourSkypeName".',
                'settings' => array(
                    array(
                        'id' => 'icons_service',
                        'label' => 'Choose service',
                        'type' => 'select',
                        'choices' => array(
                            //	Value maps to the Icon font
                            array('value' => 'fa fa-facebook', 'label' => 'Facebook', 'src' => ''),
                            array('value' => 'fa fa-google-plus', 'label' => 'Google+', 'src' => ''),
                            array('value' => 'fa fa-pinterest-p', 'label' => 'Pinterest', 'src' => ''),
                            array('value' => 'fa fa-skype', 'label' => 'Skype', 'src' => ''),
                            array('value' => 'fa fa-twitter', 'label' => 'Twitter', 'src' => ''),
                            array('value' => 'fa fa-linkedin', 'label' => 'LinkedIn', 'src' => ''),
                            array('value' => 'fa fa-instagram', 'label' => 'Instagram', 'src' => ''),
                            array('value' => 'fa fa-youtube-play', 'label' => 'Youtube', 'src' => ''),
                            array('value' => 'fa fa-vimeo', 'label' => 'Vimeo', 'src' => ''),
                            array('value' => 'fa fa-tumblr', 'label' => 'Tumblr', 'src' => ''),
                            array('value' => 'fa fa-xing', 'label' => 'Xing', 'src' => ''),
                            array('value' => 'fa fa-dribbble', 'label' => 'Dribble', 'src' => ''),
                            array('value' => 'fa fa-vk', 'label' => 'VK', 'src' => ''),
                        ),
                    ),

                    array(
                        'label' => 'URL to profile page',
                        'id' => 'icons_url',
                        'type' => 'text',
                    )

                ),
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),

            array(
                'label' => 'Show Social Icons in Mobile Menu',
                'id' => 'subheader_social_icons_show_in_mobile',
                'type' => 'on_off',
                'std' => 'on',
                'desc' => 'Have your subheader Social Icons display at the bottom of your Mobile Menu',
                'section' => 'header',
            ),

            array(
                'id' => 'tab_transparent_header',
                'label' => 'Transparent Header',
                'type' => 'tab',
                'section' => 'header'
            ),
            array(
                'label' => 'Upload Transparent Header Logo version',
                'id' => 'logo_transparent_upload',
                'type' => 'upload',
                'desc' => 'Upload your Transparent Header logo version here. Activate your transparent header on a per page basis within the Page Settings when editing a page. Once a user scrolls down it will be substituted with the default logo version.',
				'class'   => 'ot-upload-attachment-id hidden_field',
                'section' => 'header',
            ),
            array(
                'label' => 'Upload Transparent Header Retina Logo (optional)',
                'id' => 'logo_transparent_upload_retina',
                'type' => 'upload',
                'desc' => 'Upload a Transparent Header Retina Logo version here if you want to override your default transparent header logo for Retina screens (only if your default one looks blurry on high resolution screens). Make sure it is double the size of the regular transparent header Logo, for example if your logo is 200x50 your Retina logo should be 400x100.',
				'class'   => 'hidden_field',
                'section' => 'header',
            ),

            array(
                'label' => 'Transparent Logo Transition Effect',
                'id' => 'transparent_logo_effect',
                'type' => 'select',
                'desc' => 'Once a user scrolls down when using the Sticky Header the logo will be switched to the default logo using this effect',
                'choices' => array(
                    array(
                        'label' => 'Flip',
                        'value' => 'flip'
                    ),
                    array(
                        'label' => 'Fade',
                        'value' => 'fade'
                    )
                ),
                'std' => 'flip',
                'section' => 'header',
            ),

            array(
                'label' => 'Transparent Header Background Color',
                'id' => 'transparent_header_color',
                'type' => 'colorpicker',
                'desc' => 'Change your Transparent Header Background Color',
                'section' => 'header',
                'std' => '#ffffff',
            ),
            array(
                'label' => 'Transparent Header Opacity',
                'id' => 'transparent_header_opacity',
                'desc' => 'Set your Transparent Header Opacity',
                'std' => '0.1',
                'type' => 'numeric-slider',
                'section' => 'header',
                'min_max_step' => '0,1,0.05'
            ),
            array(
                'label' => 'Transparent Header Logo Section Background Color (Angular Menu only)',
                'id' => 'transparent_angular_main_navigation_logo_background',
                'type' => 'colorpicker',
                'desc' => 'Overwrite Logo section background color for the Transparent Header\'s <strong>Angular Menu</strong>',
                'section' => 'header',
                'std' => '#ffffff',
				'condition' => "navigation_style:is(menu_angular_style)",
            ),			

            array(
                'label' => 'Transparent Header Main Navigation Text Color',
                'id' => 'transparent_header_navigation_color',
                'type' => 'colorpicker',
                'desc' => 'Overwrite your Main Navigation color for your Transparent header. If using the Stripe Navigation Style (under Main Navigation tab) this color is applied to the "Search" and "Shopping Cart" icons that are in the header.',
                'section' => 'header',
                'std' => '#ffffff',
            ),

            array(
                'label' => 'Transparent Header Main Navigation Hover Text Color',
                'id' => 'transparent_header_navigation_hover_color',
                'type' => 'colorpicker',
                'desc' => 'Overwrite your Main Navigation Hover color for your Transparent header',
                'section' => 'header',
                'std' => '#ffffff',
            ),


            array(
                'label' => 'SubHeader Background Color for Transparent Header',
                'id' => 'subheader_transparent_header_bgr_color',
                'type' => 'colorpicker-opacity',
                'desc' => 'Change your SubHeader Background Color for your Transparent Header',
                'std' => '#0bafc7',
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),
            array(
                'label' => 'SubHeader Text Color for Transparent Header',
                'id' => 'subheader_transparent_header_text_color',
                'type' => 'colorpicker',
                'desc' => 'Change your SubHeader Text Color for your Transparent Header',
                'std' => '#c9c9c9',
                'section' => 'header',
                'condition' => "subheader:is(on)",
            ),

			array(
                'id' => 'tab_mobile_header',
                'label' => 'Mobile Header',
                'type' => 'tab',
                'section' => 'header'
            ),
			
            array(
                'label' => 'Search Field in the Mobile Header',
                'id' => 'mobile_show_search',
                'desc' => 'You can choose "Off" if you want to hide the Search Field in the Header for Mobile Devices',
                'type' => 'on_off',
                'std' => 'off',
                'section' => 'header',
            ),

            array(
                'label' => 'Override Mobile Default Background Color',
                'id' => 'mobile_header_bgr',
                'type' => 'colorpicker',
                'desc' => 'Change your Mobile Background Color. Default is white (#ffffff).',
                'std' => '#ffffff',
                'section' => 'header',
            ),
            array(
                'label' => 'Override Mobile Default Hamburger Menu Color',
                'id' => 'mobile_header_text_color',
                'type' => 'colorpicker',
                'desc' => 'Change your Mobile Background Color. Default is dark grey (#333333).',
                'std' => '#333333',
                'section' => 'header',
            ),
			
            array(
                'label' => 'Mobile Header always sticky',
                'id' => 'mobile_header_always_sticky',
                'desc' => 'By default (OFF) the mobile header hides when a user scrolls down, if you enable this option (ON) it always stays sticky.',
                'type' => 'on_off',
                'std' => 'off',
                'section' => 'header',
            ),
			
            array(
                'label' => 'Override Mobile Logo (optional)',
                'id' => 'mobile_logo_upload',
                'type' => 'upload',
                'desc' => 'If you want to use a different logo rather than your main logo for mobile devices you can upload it here. If none is uploaded your default logo from MAIN tab will be used for your Mobile Header.',
				'class'   => 'ot-upload-attachment-id hidden_field',
                'section' => 'header',
            ),
            array(
                'label' => 'Override Retina Logo for Mobile (optional)',
                'id' => 'mobile_logo_upload_retina',
                'type' => 'upload',
                'desc' => 'If you want to use a different Retina logo than your main Retina logo for mobile devices you can upload it here. If none is uploaded your default Retina logo from MAIN tab will be used for your Mobile Header.',
				'class'   => 'hidden_field',
                'section' => 'header',
            ),
			
            array(
                'label' => 'Hide Wordpress Admin Bar in mobile',
                'id' => 'hide_admin_bar',
                'type' => 'on_off',
                'desc' => 'Hide the dark Admin bar on top in mobile devices when logged in Wordpress for testing purposes',
                'std' => 'on',
                'section' => 'header',
                'condition' => "sticky_header:is(on)",
            ),			
			
			
			array(
				'label'       => 'Google Fonts API key',
				'id'          => 'google_fonts_api_key',
				'type'        => 'text',
				'desc'        => 'Enter your Google Fonts API key here and click "SAVE CHANGES". <a href="https://developers.google.com/fonts/docs/developer_api#APIKey" target="_blank">Get one here</a>.',
				'section'     => 'typography',
			),			
			

            array(
                'label' => 'Add Google Fonts to your Website',
                'id' => 'google_fonts',
                'desc' => 'Select the Google Fonts you want to use. Once you click "SAVE CHANGES" they will be added as options into the Font-Family dropdowns below. By default the theme adds automatically "Open Sans" (400,600), "Montserrat" (300,400,600,700) Google Fonts so you don\'t have to add those unless you use a weight other than the ones listed above.',
                'type' => 'google-fonts',
                'section' => 'typography',
            ),

            array(
                'label' => 'Main Navigation Font (Top Level Items)',
                'id' => 'nav_font',
                'desc' => 'Choose your Main Navigation Font (Default is Montserrat).<br> Have in mind some Google fonts do not support all font-weights, when adding it you will see what styles the font supports.',
                'std' => array('font-family' => 'montserrat', 'font-size' => '14px', 'font-weight' => '500', 'text-transform' => 'capitalize', 'letter-spacing' => ''),
                'type' => 'typography',
                'section' => 'typography',
            ),

            array(
                'label' => 'Main Sub-Navigation Font (Submenu items/Drop Down Menu Items)',
                'id' => 'sub_nav_font',
                'desc' => 'Choose your Main Navigation Sub Menu Font (Default is Montserrat).<br> Have in mind some Google fonts do not support all font-weights, when adding it you will see what styles the font supports.',
                'std' => array('font-family' => 'montserrat', 'font-size' => '13px', 'font-weight' => 'normal', 'text-transform' => 'capitalize', 'letter-spacing' => ''),
                'type' => 'typography',
                'section' => 'typography',
            ),

            array(
                'label' => 'Heading Font',
                'id' => 'heading_font',
                'desc' => 'Choose Font Family for your headings (H1-H6). (Default is Montserrat). Have in mind some Google fonts do not support all font-weights, when adding it you will see what styles the font supports.',
                'std' => array('font-family' => 'montserrat', 'font-weight' => '500', 'text-transform' => 'uppercase', 'letter-spacing' => '-0.02em'),
                'type' => 'typography',
                'section' => 'typography',
            ),

            array(
                'label' => 'Body Font',
                'id' => 'body_font',
                'desc' => 'Choose Font Family for body. (Default is Open Sans).',
                'std' => array('font-family' => 'opensans', 'font-color' => '#333', 'font-size' => '16px', 'font-weight' => '400', 'line-height' => '1.7em'),
                'type' => 'typography',
                'section' => 'typography',
            ),

            array(
                'label' => 'Button Font',
                'id' => 'button_font',
                'desc' => 'Choose Font Family for your Buttons and Button Links. (Default is Montserrat). You can further style your buttons in the editor.',
                'std' => array('font-family' => 'opensans', 'font-size' => '13px', 'font-weight' => '600', 'text-transform' => 'uppercase', 'letter-spacing' => '0.05em'),
                'type' => 'typography',
                'section' => 'typography',
            ),

            array(
                'label' => 'Wrapper Style',
                'id' => 'wrapper_style',
                'type' => 'select',
                'desc' => 'Select your Wrapper style. This value can be changed on a per Page basis under Page Settings.',
                'choices' => array(
                    array(
                        'label' => 'Boxed',
                        'value' => 'boxed_wrapper'
                    ),
                    array(
                        'label' => 'Full Width',
                        'value' => 'full_width_wrapper'
                    )
                ),
                'std' => 'full_width_wrapper',
                'section' => 'general'
            ),

            array(
                'label' => 'Wrapper Width',
                'id' => 'wrapper_width',
                'type' => 'select',
                'desc' => 'The wrapper holds a design within certain boundaries (on large screens). It is the usable are of the page where elements would reside (unless you are using a full width row).',
                'choices' => array(
                    array(
                        'label' => '1260px',
                        'value' => ''
                    ),
                    array(
                        'label' => '1380px',
                        'value' => 'w1380'
                    ),
                    array(
                        'label' => '1500px',
                        'value' => 'w1500'
                    )
                ),
                'std' => '',
                'section' => 'general'
            ),


            array(
                'label' => 'Global Background',
                'id' => 'boc_page_global_bgr',
                'desc' => 'Select the global Background color/image. This value can be changed on a per Page basis under Page Settings. Type "cover" for background-size if you want the background image to stretch full width.',
                'type' => 'background',
                'section' => 'general',
				'condition' => "wrapper_style:is(boxed_wrapper)",
            ),

            array(
                'label' => 'Enable Responsive Design',
                'id' => 'responsive_design',
                'type' => 'on_off',
                'section' => 'general',
                'std' => 'on',
                'desc' => 'Turn if OFF only if you absolutely have to and have in mind that things like Sticky/Transparent Header & Unrolling Footer cannot be used. Make sure you also Turn Off WPBakery Page Builder\'s Responsiveness from Dashboard -> WPBakery Page Builder.'
            ),

			
            array(
                'label' => 'Enable SCROLL TO TOP button',
                'id' => 'scroll_to_top',
                'type' => 'on_off',
                'section' => 'general',
                'std' => 'on',
                'desc' => 'Enable the Scroll To Top button in the bottom right'
            ),
			
			
            array(
                'label' => 'Hide Core WPBakery Page Builder elements',
                'id' => 'boc_hide_core_vc_elements',
                'type' => 'on_off',
                'std' => 'on',
                'desc' => 'Hide WPBakery Page Builder plugin core elements',
                'section' => 'general'
            ),	
			
            array(
                'label' => 'Disable WPBakery Page Builder Front End Editor',
                'id' => 'boc_disable_vc_frontend_editor',
                'type' => 'on_off',
                'std' => 'on',
                'desc' => '',
                'section' => 'general'
            ),			

/*
            array(
                'label' => 'Enable Retina Support',
                'id' => 'retina',
                'type' => 'on_off',
                'section' => 'general',
                'std' => 'off',
                'desc' => 'This will swap images with larger image-size alternatives if available on Retina supported screens.',
            ),
*/
            array(
                'label' => 'Smooth Scroll',
                'id' => 'smooth_scrolling',
                'type' => 'on_off',
                'std' => 'off',
                'desc' => 'Scrolling with the mouse creates a smooth movement effect.',
                'section' => 'general'
            ),

            array(
                'label' => 'Preloader Animation - Spinner Icon',
                'id' => 'has_page_preloader',
                'type' => 'on_off',
                'std' => 'off',
                'desc' => 'A Spinning Circle Icon will appear until the current page is fully loaded. If this global option is OFF you can still switch to ON on a per page basis from Page Settings.',
                'section' => 'general'
            ),

            array(
                'label' => 'Page Heading Style',
                'id' => 'page_heading_style',
                'type' => 'select',
                'desc' => 'Change your Page Heading (the area below Header) Style from here.',
                'choices' => array(
                    array(
                        'label' => 'Default',
                        'value' => 'page_title_bgr'
                    ),
                    array(
                        'label' => 'Triangles BGR',
                        'value' => 'page_title_bgr bgr_style1'
                    ),
                    array(
                        'label' => 'Custom',
                        'value' => 'page_title_bgr custom_bgr'
                    ),
                ),
                'std' => 'page_title_bgr bgr_style1',
                'section' => 'general'
            ),


            array(
                'label' => 'Page Heading Custom Background',
                'id' => 'boc_page_heading_style_bgr',
                'desc' => 'Select a custom background for your regular page heading.',
                'type' => 'background',
                'section' => 'general',
                'condition' => "page_heading_style:is(page_title_bgr custom_bgr)",
            ),

            array(
                'label' => 'Page Heading White Text Color',
                'id' => 'boc_page_heading_white_text',
                'type' => 'on_off',
                'std' => 'off',
                'desc' => 'Force White color for Page Heading text (use when using a dark BGR for your Page Heading)',
                'section' => 'general'
            ),

            array(
                'label' => 'Enable breadcrumbs',
                'id' => 'breadcrumbs',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'general'
            ),
            array(
                'label' => 'Breadcrumb Position',
                'id' => 'breadcrumbs_position',
                'type' => 'select',
                'desc' => 'Change your Page Heading (the area below Header) Style from here.',
                'choices' => array(
                    array(
                        'label' => 'Floated to the side',
                        'value' => 'floated'
                    ),
                    array(
                        'label' => 'Centered Below Title',
                        'value' => 'centered'
                    ),
				  array(
                        'label' => 'Above Title',
                        'value' => 'normal'
                    ),
                ),
                'std' => 'floated',
                'section' => 'general'
            ),


            array(
                'label' => 'Enable Comments for Pages',
                'id' => 'show_page_comments',
                'type' => 'on_off',
                'std' => 'on',
			   'desc' => 'Plugin Required',
                'section' => 'general'
            ),
			
			
            array(
                'label' => 'Enable SVG File Upload',
                'id' => 'enable_svg_upload',
                'type' => 'on_off',
                'std' => 'off',
                'section' => 'general'
            ),			


            array(
                'label' => 'Image Edges',
                'id' => 'rounded_images',
                'type' => 'select',
                'desc' => 'Add Border Radius to your Images globally',
                'choices' => array(
                    array(
                        'label' => 'Square',
                        'value' => 0
                    ),
                    array(
                        'label' => 'Rounded',
                        'value' => 1
                    )
                ),
                'std' => 0,
                'section' => 'general'
            ),


            array(
                'label' => 'Footer BGR Color',
                'id' => 'footer_style',
                'type' => 'select',
                'choices' => array(
                    array(
                        'label' => 'Light',
                        'value' => 0
                    ),
                    array(
                        'label' => 'Dark',
                        'value' => 1
                    )
                ),
                'std' => 1,
                'section' => 'footer'
            ),
/*
            array(
                'label' => 'Footer Columns (Widget Areas)',
                'id' => 'footer_columns',
                'type' => 'select',
                'choices' => array(
                    array(
                        'label' => 'None',
                        'value' => 0
                    ),
                    array(
                        'label' => '1',
                        'value' => 1
                    ),
                    array(
                        'label' => '2',
                        'value' => 2
                    ),
                    array(
                        'label' => '3',
                        'value' => 3
                    ),
                    array(
                        'label' => '4',
                        'value' => 4
                    )
                ),
                'std' => 0,
                'section' => 'footer',
                'desc' => 'How Many columns you want your footer to display'
            ),
*/
            array(
                'label' => 'Footer Fixed Position',
                'id' => 'footer_position',
                'type' => 'select',
                'desc' => 'Set to "Fixed" if you want the unrolling footer effect like in the Demo. Make sure your pages are long enough for this option, otherwise your footer may look awkward.',
                'choices' => array(
                    array(
                        'label' => 'Normal',
                        'value' => 0
                    ),
                    array(
                        'label' => 'Fixed',
                        'value' => 1
                    )
                ),
                'std' => 0,
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => '',
                'section' => 'footer'
            ),

            array(
                'label' => 'Copyrights Text in Footer',
                'id' => 'copyrights',
                'type' => 'text',
                'desc' => 'Copyrights Text in Footer',
                'std' => boc_get_footer_copyright_text(),
                'section' => 'footer'
            ),

            array(
                'label' => 'Footer Social Icons',
                'id' => 'footer_icons',
                'type' => 'list-item',
                'desc' => 'Manage your Socials Icons in the theme footer. For Skype URL use "callto://YourSkypeName".',
                'settings' => array(
                    array(
                        'id' => 'icons_service_footer',
                        'label' => 'Choose service',
                        'type' => 'select',
                        'choices' => array(
                            //	Value maps to the Icon font
                            array('value' => 'fa fa-facebook', 'label' => 'Facebook', 'src' => ''),
                            array('value' => 'fa fa-google-plus', 'label' => 'Google+', 'src' => ''),
                            array('value' => 'fa fa-pinterest-p', 'label' => 'Pinterest', 'src' => ''),
                            array('value' => 'fa fa-skype', 'label' => 'Skype', 'src' => ''),
                            array('value' => 'fa fa-twitter', 'label' => 'Twitter', 'src' => ''),
                            array('value' => 'fa fa-linkedin', 'label' => 'LinkedIn', 'src' => ''),
                            array('value' => 'fa fa-instagram', 'label' => 'Instagram', 'src' => ''),
                            array('value' => 'fa fa-youtube-play', 'label' => 'Youtube', 'src' => ''),
                            array('value' => 'fa fa-vimeo', 'label' => 'Vimeo', 'src' => ''),
                            array('value' => 'fa fa-tumblr', 'label' => 'Tumblr', 'src' => ''),
                            array('value' => 'fa fa-xing', 'label' => 'Xing', 'src' => ''),
                            array('value' => 'fa fa-dribbble', 'label' => 'Dribble', 'src' => ''),
                            array('value' => 'fa fa-vk', 'label' => 'VK', 'src' => ''),
                        ),
                    ),

                    array(
                        'label' => 'URL to profile page',
                        'id' => 'icons_url_footer',
                        'type' => 'text',
                    )

                ),
                'section' => 'footer'
            ),


            array(
                'id' => 'tab_blog_general',
                'label' => 'General',
                'type' => 'tab',
                'section' => 'blog',
            ),			


            array(
                'label' => 'Enable "LIKE" functionality for Posts',
                'id' => 'posts_like_functionality',
                'type' => 'on_off',
                'std' => 'off',
                'section' => 'blog'
            ),
			

            array(
                'label' => 'Enable "Previous/Next Post" Arrows in Single Post',
                'id' => 'prev_next_posts',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
			
            array(
                'label' => '"Read More" Link Style',
                'id' => 'blog_more_link_style',
                'type' => 'select',
                'desc' => 'Choose a Style for your "Read More" link',
                'std' => '1',
                'section' => 'blog',
                'choices' => array(
                    array(
                        'label' => 'Simple',
                        'value' => '0'
                    ),
                    array(
                        'label' => 'With Arrow Icon',
                        'value' => '1'
                    ),
                ),
            ),
			
			
            array(
                'label' => 'Post Date Format',
                'id' => 'post_date_format',
                'type' => 'select',
                'desc' => 'Choose a Format for your Post dates',
                'std' => '1',
                'section' => 'blog',
                'choices' => array(
                    array(
                        'label' => 'Date: i.e. "24 Mar 2018"',
                        'value' => '1'
                    ),
                    array(
                        'label' => 'Time Ago i.e. "5 days ago"',
                        'value' => '2'
                    ),
                ),
            ),
	
			array(
                'id' => 'tab_blog_posts',
                'label' => 'Blog Page Style',
                'type' => 'tab',
                'section' => 'blog',
            ),				
			

            array(
                'label' => 'Full height Featured Images on Blog List Page',
                'desc' => 'By default (when OFF) a cropped, smaller height version is used (1200x600).',
                'id' => 'blog_full_img_height',
                'type' => 'on_off',
                'std' => 'off',
                'section' => 'blog',
				'condition' => "blog_format:is(1)",
            ),


            array(
                'label' => 'Excerpt Word limit',
                'id' => 'blog_excerpt_limit',
                'type' => 'text',
				'desc' => 'Choose how many words you want your post excerpts limited to on your Blog List Page (Default is 55)',
                'std' => '55',
                'section' => 'blog',
            ),			

            array(
                'label' => 'Show "Author" Meta for Blog List Page',
                'id' => 'blog_meta_author',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
            array(
                'label' => 'Show "Date" Meta for Blog List Page',
                'id' => 'blog_meta_date',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
            array(
                'label' => 'Show "Comments Link" Meta for Blog List Page',
                'id' => 'blog_meta_comments',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
            array(
                'label' => 'Show Categories Meta for Blog List Page',
                'id' => 'blog_meta_cats',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
            array(
                'label' => 'Show Tags Meta for Blog List Page',
                'id' => 'blog_meta_tags',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
            array(
                'label' => 'Show "Like Button" for Blog List Page',
                'id' => 'blog_meta_like',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
			
			
			

            array(
                'id' => 'tab_blog_single_post',
                'label' => 'Single Post Style',
                'type' => 'tab',
                'section' => 'blog',
            ),				
			
            array(
                'label' => 'Blog Post Style',
                'id' => 'blog_post_format',
                'type' => 'select',
                'desc' => 'Choose the Single Post style to use globally (can be overridden on a per Post basis)',
                'std' => '1',
                'section' => 'blog',
                'choices' => array(
                    array(
                        'label' => 'Featured Image above content',
                        'value' => 'regular'
                    ),
                    array(
                        'label' => 'Full Width Featured Image as Background',
                        'value' => 'full'
                    ),
                    array(
                        'label' => 'Side Meta Data',
                        'value' => 'side'
                    ),
                ),
            ),
			
            array(
                'label' => 'What to display below title (for Full Width Style)',
                'id' => 'blog_post_full_display_below_title',
                'type' => 'select',
                'std' => '2',
                'section' => 'blog',
                'choices' => array(
                    array(
                        'label' => 'None',
                        'value' => '0'
                    ),
                    array(
                        'label' => 'Breadcrumbs',
						'value' => '1'
                    ),
					array(
						'label' => 'Meta Data',
						'value' => '2'
                    ),
                ),
				'condition' => "blog_post_format:is(full)",
            ),
			

            array(
                'label' => 'Full height Featured Images on a Single Post',
                'desc' => 'By default (when ON) the full image version will be shown. Switch to OFF to show a cropped, smaller height version (1200x600) for a Single Post.',
                'id' => 'blog_post_full_img_height',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog',
				'condition' => "blog_post_format:is(regular)",
            ),
			

            array(
                'label' => 'Show "Author" Meta for Single Post templates',
                'id' => 'blog_post_meta_author',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
            array(
                'label' => 'Show "Date" Meta for Single Post templates',
                'id' => 'blog_post_meta_date',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
            array(
                'label' => 'Show "Comments Link" Meta for Single Post templates',
                'id' => 'blog_post_meta_comments',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
            array(
                'label' => 'Show Categories Meta for Single Post templates',
                'id' => 'blog_post_meta_cats',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
            array(
                'label' => 'Show Tags Meta for Single Post templates',
                'id' => 'blog_post_meta_tags',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),
            array(
                'label' => 'Show "Like Button" for Single Post templates',
                'id' => 'blog_post_meta_like',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'blog'
            ),

		



			
			
			
            array(
                'label' => 'WooCommerce layout',
                'id' => 'woocommerce_sidebar_layout',
                'type' => 'radio-image',
                'desc' => 'Choose Sidebar Layout for your WooCommerce Pages',
                'std' => 'no-sidebar',
                'section' => 'woocommerce',
                'choices' => array(
                    array(
                        'value' => 'no-sidebar',
                        'label' => 'No Sidebar',
                        'src' => OT_URL . '/assets/images/layout/full-width.png'
                    ),
                    array(
                        'value' => 'right-sidebar',
                        'label' => 'Right Sidebar',
                        'src' => OT_URL . '/assets/images/layout/right-sidebar.png'
                    ),
                    array(
                        'value' => 'left-sidebar',
                        'label' => 'Left Sidebar',
                        'src' => OT_URL . '/assets/images/layout/left-sidebar.png'
                    ),
                ),
            ),
            array(
                'label' => 'WooCommerce Single Product Page layout',
                'id' => 'woocommerce_single_product_sidebar_layout',
                'type' => 'radio-image',
                'desc' => 'Choose Sidebar Layout for your WooCommerce Product Pages - That would be a page where a single product is displayed.',
                'std' => 'no-sidebar',
                'section' => 'woocommerce',
                'choices' => array(
                    array(
                        'value' => 'no-sidebar',
                        'label' => 'No Sidebar',
                        'src' => OT_URL . '/assets/images/layout/full-width.png'
                    ),
                    array(
                        'value' => 'right-sidebar',
                        'label' => 'Right Sidebar',
                        'src' => OT_URL . '/assets/images/layout/right-sidebar.png'
                    ),
                    array(
                        'value' => 'left-sidebar',
                        'label' => 'Left Sidebar',
                        'src' => OT_URL . '/assets/images/layout/left-sidebar.png'
                    ),
                ),
            ),

            array(
                'label' => 'Products per Page',
                'id' => 'woocommerce_products_per_page',
                'type' => 'select',
                'std' => '12',
                'choices' => array(
                    array(
                        'label' => '9',
                        'value' => '9'
                    ),
                    array(
                        'label' => '12',
                        'value' => '12'
                    ),
                    array(
                        'label' => '16',
                        'value' => '16'
                    ),
                    array(
                        'label' => '24',
                        'value' => '24'
                    ),
                    array(
                        'label' => '48',
                        'value' => '48'
                    )
                ),
                'section' => 'woocommerce',
                'desc' => 'Products per Page on product listing pages like Shop, Category etc.',
            ),


            array(
                'label' => 'Enable WooCommerce Shopping Cart in Header',
                'id' => 'woocommerce_cart_in_header',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'woocommerce'
            ),

            array(
                'label' => 'Background Color for WooCommerce Shopping Cart in Header',
                'id' => 'woocommerce_cart_in_header_bgr_color',
                'type' => 'select',
                'std' => 'style_dark',
                'choices' => array(
                    array(
                        'label' => 'Dark',
                        'value' => 'style_dark'
                    ),
                    array(
                        'label' => 'White',
                        'value' => 'style_white'
                    )
                ),
                'section' => 'woocommerce',
                'condition' => "woocommerce_cart_in_header:is(on)",
            ),
			

            array(
                'label' => 'Force Header Search Product Searching',
                'id' => 'woocommerce_header_product_search',
                'type' => 'on_off',
                'std' => 'off',
				'desc' => 'Switch this ON if you want the website search in the header to work for Woocommerce products and use the Woocommerce template for the search results',
                'section' => 'woocommerce'
            ),			

            array(
                'label' => 'Static Content on top of your Shop page (great for adding sliders)',
                'id' => 'woo_static_top_content',
                'type' => 'textarea',
                'desc' => 'This is some static content that will go on top of your Shop page. Perfect for adding sliders (Revolution slider for example) as normal page content for the Shop page entered via the WP editor is rendered above the products. So if you have a sidebar on your Shop page a full width slider would mess up your layout.',
                'section' => 'woocommerce'
            ),


            array(
                'label' => 'Default <b>Page</b> Sidebar Layout',
                'id' => 'sidebar_layout',
                'type' => 'radio-image',
                'desc' => 'Choose default Sidebar Layout for your Pages. This value can be overwritten and set on a per-page basis while editing a page.',
                'std' => 'full-width',
                'section' => 'sidebars',
                'choices' => array(
                    array(
                        'value' => 'full-width',
                        'label' => 'Full Width',
                        'src' => OT_URL . '/assets/images/layout/full-width.png'
                    ),
                    array(
                        'value' => 'right-sidebar',
                        'label' => 'Right Sidebar',
                        'src' => OT_URL . '/assets/images/layout/right-sidebar.png'
                    ),
                    array(
                        'value' => 'left-sidebar',
                        'label' => 'Left Sidebar',
                        'src' => OT_URL . '/assets/images/layout/left-sidebar.png'
                    ),
                ),
            ),

            array(
                'label' => 'Default <b>Blog Listing</b> Sidebar Layout',
                'id' => 'sidebar_layout_posts',
                'type' => 'radio-image',
                'desc' => 'Choose default Sidebar Layout for your Blog Listing page. This Layout will also be used for your Category & Taxonomy post list pages.',
                'std' => 'right-sidebar',
                'section' => 'sidebars',
                'choices' => array(
                    array(
                        'value' => 'full-width',
                        'label' => 'Full Width',
                        'src' => OT_URL . '/assets/images/layout/full-width.png'
                    ),
                    array(
                        'value' => 'right-sidebar',
                        'label' => 'Right Sidebar',
                        'src' => OT_URL . '/assets/images/layout/right-sidebar.png'
                    ),
                    array(
                        'value' => 'left-sidebar',
                        'label' => 'Left Sidebar',
                        'src' => OT_URL . '/assets/images/layout/left-sidebar.png'
                    ),
                ),
            ),


            array(
                'label' => 'Default <b>Single Post</b> Sidebar Layout',
                'id' => 'sidebar_layout_single_post',
                'type' => 'radio-image',
                'desc' => 'Choose default Sidebar Layout for your Single Posts. This value can be overwritten and set on a per-page basis while editing a post.',
                'std' => 'full-width',
                'section' => 'sidebars',
                'choices' => array(
                    array(
                        'value' => 'full-width',
                        'label' => 'Full Width',
                        'src' => OT_URL . '/assets/images/layout/full-width.png'
                    ),
                    array(
                        'value' => 'right-sidebar',
                        'label' => 'Right Sidebar',
                        'src' => OT_URL . '/assets/images/layout/right-sidebar.png'
                    ),
                    array(
                        'value' => 'left-sidebar',
                        'label' => 'Left Sidebar',
                        'src' => OT_URL . '/assets/images/layout/left-sidebar.png'
                    ),
                ),
            ),


            array(
                'id' => 'sidebars_text',
                'label' => 'About sidebars',
                'desc' => 'All Dynamic sidebars that you create here will appear both in the Appearance > Widgets. You can then assign them to specific pages or posts.',
                'type' => 'textblock',
                'section' => 'sidebars',
            ),

            array(
                'label' => 'Create Sidebars',
                'id' => 'boc_sidebars',
                'type' => 'list-item',
                'desc' => 'Choose a unique title for each sidebar',
                'section' => 'sidebars',
				'class'	=> 'not-sortable',
                'settings' => array(
                    array(
                        'label' => 'ID',
                        'id' => 'id',
                        'type' => 'text',
                        'desc' => 'Write a lowercase single word as ID (no spaces & it shouldn\'t start with a digit)',
                    )
                )
            ),

            array(
                'label' => 'Portfolio Slug',
                'id' => 'portfolio_slug',
                'type' => 'text',
                'desc' => 'Enter the URL Slug for your Portfolio Items (Default: portfolio_item) <br /><strong>Go to Settings -> Permalinks and Save your permalinks after changing this.</strong>',
                'section' => 'portfolio',
                'std' => 'portfolio_item',
            ),

            array(
                'label' => 'Image Cropping',
                'id' => 'portfolio_img_size',
                'type' => 'select',
                'desc' => 'Original - preserves default image proportions, Cropped - Uses the theme preset (600x380) cropped image version',
                'choices' => array(
                    array(
                        'label' => 'Original Size (No Crop)',
                        'value' => 'full'
                    ),
                    array(
                        'label' => 'Cropped (Same Height Effect)',
                        'value' => 'boc_medium'
                    ),
                ),
                'section' => 'portfolio',
                'std' => 'boc_medium',
            ),

            array(
                'label' => 'Portfolio Preset Style',
                'id' => 'portfolio_style',
                'type' => 'select',
                'desc' => 'Choose one of the available presets for displaying your portfolio items for the Portfolio Filter Page and the Related Portfolio Items',
                'choices' => array(
                    array(
                        'label' => 'Style 1',
                        'value' => 'type1'
                    ),
                    array(
                        'label' => 'Style 2',
                        'value' => 'type2'
                    ),
                    array(
                        'label' => 'Style 3',
                        'value' => 'type3'
                    ),
                    array(
                        'label' => 'Style 4',
                        'value' => 'type4'
                    ),
                    array(
                        'label' => 'Style 5',
                        'value' => 'type5'
                    ),
                    array(
                        'label' => 'Style 6',
                        'value' => 'type6'
                    ),
                    array(
                        'label' => 'Style 7',
                        'value' => 'type7'
                    ),
                    array(
                        'label' => 'Style 8',
                        'value' => 'type8'
                    ),
                    array(
                        'label' => 'Style 9',
                        'value' => 'type8 light'
                    )
                ),
                'std' => 'type1',
                'section' => 'portfolio'
            ),

            array(
                'label' => 'Show "Plus" icon on hover',
                'id' => 'portfolio_hover_icon',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'portfolio'
            ),
			
			
            array(
                'label' => 'Portfolio Hover Effect',
                'id' => 'portfolio_img_hover_effect',
                'type' => 'select',
                'desc' => 'Choose one of the available portfolio Item img Hover effects for your Portfolio Filter Page',
                'choices' => array(
                    array(
                        'label' => 'None',
                        'value' => 'none'
                    ),
                    array(
                        'label' => 'Zoom Out',
                        'value' => '1'
                    ),
                    array(
                        'label' => 'Zoom In',
                        'value' => '2'
                    ),
                    array(
                        'label' => 'Side',
                        'value' => '3'
                    ),
                    array(
                        'label' => 'Spin',
                        'value' => '4'
                    )
                ),
                'std' => '2',
                'section' => 'portfolio'
            ),

            array(
                'label' => 'Portfolio Item Order Clause',
                'id' => 'portfolio_order',
                'type' => 'select',
                'desc' => 'Choose the Order clause type for your Portfolio Filter Page (Descending or Ascending)',
                'choices' => array(
                    array(
                        'label' => 'DESC',
                        'value' => 'DESC'
                    ),
                    array(
                        'label' => 'ASC',
                        'value' => 'ASC'
                    ),
                ),
                'section' => 'portfolio'
            ),

            array(
                'label' => 'Portfolio Item OrderBy Clause',
                'id' => 'portfolio_orderby',
                'type' => 'select',
                'desc' => 'Choose the OrderBy clause type for your Portfolio Filter Page',
                'choices' => array(
                    array(
                        'label' => 'Date',
                        'value' => 'date'
                    ),
                    array(
                        'label' => 'Title',
                        'value' => 'title'
                    ),
                    array(
                        'label' => 'Name',
                        'value' => 'name'
                    ),
                    array(
                        'label' => 'ID',
                        'value' => 'ID'
                    ),
                    array(
                        'label' => 'Random',
                        'value' => 'rand'
                    ),
                ),
                'section' => 'portfolio'
            ),


            array(
                'label' => 'Portfolio Item Spacing',
                'id' => 'portfolio_items_spacing',
                'type' => 'select',
                'desc' => 'Choose whether you want spacing or not for your Portfolio items on your Portfolio Filter Page',
                'choices' => array(
                    array(
                        'label' => 'Big Spacing',
                        'value' => 'big_spacing'
                    ),
                    array(
                        'label' => 'Small Spacing',
                        'value' => 'small_spacing'
                    ),
                    array(
                        'label' => 'No Spacing',
                        'value' => 'no_spacing'
                    ),
                ),
                'std' => 'big_spacing',
                'section' => 'portfolio'
            ),

            array(
                'label' => 'Enable Related Projects in Portfolio',
                'id' => 'related_portfolio_projects',
                'type' => 'on_off',
                'std' => 'on',
                'section' => 'portfolio'
            ),

            array(
                'label' => 'Portfolio Items per Page',
                'id' => 'portfolio_items_per_page',
                'type' => 'text',
                'desc' => 'Enter how many items per Page you want in your Portfolio Page (Integer). Increase this number if you don\'t want pagination on your Portfolio Filter page. This might be useful as filtering the items only applies to the current set (page) of items shown.',
                'std' => '24',
                'section' => 'portfolio'
            ),
            array(
                'id' => 'custom_css',
                'label' => 'Custom CSS',
                'desc' => 'Write any custom CSS code you want here or use Child Themes to prevent data-loss upon theme updates.',
                'type' => 'css',
                'section' => 'custom_styles',
            ),
        ),


    );

    /* settings are not the same update the DB */
    if ($saved_settings !== $custom_settings) {
        update_option('option_tree_settings', $custom_settings);
    }

}


